#
# spec file for package element-desktop
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           element-desktop
Version:        1.11.69
Release:        2.1
Summary:        A glossy Matrix collaboration client - desktop
License:        Apache-2.0
URL:            https://github.com/vector-im/element-desktop
Source0:        https://github.com/vector-im/element-desktop/archive/v%{version}.tar.gz#/element-desktop-%{version}.tar.gz
Source2:        vendor.tar.zst
Source3:        io.element.Element.desktop
Source4:        element-desktop.sh
Source5:        prepare.sh
Patch0:         hak-remove-devdependencies.patch
Patch1:         7za-path.patch
Patch2:         cc-link-lib-no-static.patch
Patch3:         remove-fuses.patch
BuildRequires:  element-web = %{version}
BuildRequires:  app-builder
BuildRequires:  cargo
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  jq
BuildRequires:  nodejs-electron-devel
BuildRequires:  pkgconfig(openssl)
BuildRequires:  zstd
%if 0%{?fedora}
BuildRequires:  rust-srpm-macros
%else
BuildRequires:  cargo-packaging >= 1.2.0+3
BuildRequires:  cargo-auditable
%endif

BuildRequires:  libsecret-devel
BuildRequires:  gcc-c++
Requires:       element-web = %{version}
Requires:       nodejs-electron%{_isa}

#x86 electron requires SSE2
%ifarch %ix86
ExclusiveArch:  i586 i686
BuildArch:      i686
%{expand:%%global optflags %(echo "%optflags") -march=pentium4 -mtune=generic}
%{expand:%%global build_rustflags %(echo "%build_rustflags") -C target-cpu=pentium4 -Z tune-cpu=generic}
%endif


%description
A glossy Matrix collaboration client - desktop

%prep
%setup -q -a2
%autopatch -p1

# https://blogs.gnome.org/mcatanzaro/2020/05/18/patching-vendored-rust-dependencies/
for i in cc libloading libsqlite3-sys openssl-src rustix seshat vcpkg; do
pushd .hak/hakModules/matrix-seshat/vendor/$i
jq -cj '.files={}' .cargo-checksum.json >tmp && mv tmp .cargo-checksum.json && popd
done


jq -cj '.piwik=false | .update_base_url=null' < element.io/release/config.json > tmp && mv -v tmp element.io/release/config.json


%build
export CFLAGS="%{optflags} -fpic -fno-semantic-interposition -fno-fat-lto-objects -fvisibility=hidden"
export CXXFLAGS="%{optflags} -fpic -fno-semantic-interposition -fno-fat-lto-objects -fvisibility=hidden"
export LDFLAGS="%{?build_ldflags}"
export MAKEFLAGS="%{_smp_mflags}"
export ELECTRON_SKIP_BINARY_DOWNLOAD=1
export PLAYWRIGHT_SKIP_BROWSER_DOWNLOAD=1
export USE_SYSTEM_APP_BUILDER=true
export OPENSSL_NO_VENDOR=1
# The `cc` crate tries to be too clever and passes some default cflags when building sqlcipher.
# Disable these and use only the ones from CFLAGS env. variable
export CRATE_CC_NO_DEFAULTS=1


%ifarch %ix86
export RUSTC_BOOTSTRAP=1
%endif
#I want to actually see the build logs for Cargo. Especially the gcc command line for dependent modules.
export RUSTC_LOG='rustc_codegen_ssa::back::link=info'
export RUSTFLAGS="%{build_rustflags} --verbose -Cstrip=none"
export CARGO_TERM_VERBOSE=true

%electron_rebuild


#We do manually the rough equivalent of `hak build` to inject correct optflags
pushd .hak/hakModules/keytar
%electron_rebuild
popd

pushd .hak/hakModules/matrix-seshat
%if 0%{?suse_version}
auditable='auditable -vv'
%endif
cargo -vv $auditable rustc --offline --release --features=bundled-sqlcipher --lib --crate-type cdylib
ln -Tv target/release/*.so index.node
popd


#Compare definition of `build:universal` in package.json
npm run build:ts
npm run build:res
npx --no-install electron-builder --linux dir --universal -c.electronDist=%{_libdir}/electron -c.asar=false -c.nodeGypRebuild=false -c.npmRebuild=false




%install
#Remove sources an other files that should not be shipped
pushd dist/linux-universal-unpacked/resources/app
rm -rf node_modules/matrix-seshat/{.cargo,false,src,target,test,vendor,Cargo.lock,Cargo.toml}
find -name '*.c' -type f -print -delete
find -name '*.cc' -type f -print -delete
find -name '*.cpp' -type f -print -delete
find -name '*.h' -type f -print -delete
find -name '*.m' -type f -print -delete
find -name '*.map' -type f -print -delete
find -name '*.ts' -type f -print -delete
find -name '*.tsx' -type f -print -delete
find -name '*.gyp' -type f -print -delete
find -name '*.gypi' -type f -print -delete
find -name '*.mk' -type f -print -delete
find -name '*.Makefile' -type f -print -delete
find -name '.eslint*' -type f -print -delete
find -name .editorconfig -type f -print -delete
find -name .nvmrc -type f -print -delete
find -name .nycrc -type f -print -delete
find -name Makefile -type f -print -delete
find -name '.jscs*' -type f -print -delete
find -name obj.target -print0 |xargs -r0 -- rm -rvf --
find -name '*.d' -type f -print -delete

#Documentation
find -name '*.md' -type f -print -delete
find -name '*.markdown' -type f -print -delete
find -name '*.bnf' -type f -print -delete
find -name '*.mli' -type f -print -delete
find -name CHANGES -type f -print -delete
find -name TODO -type f -print -delete
find -name usage.txt -type f -print -delete

# Remove empty directories
find . -type d -empty -print -delete

# fix file mode
find . -type f -exec chmod 0644 {} \;
find . -name '*.node' -exec chmod 0755 {} \;
popd



# Install the app content, replace the webapp with a symlink to the system package
install -vd -m 0755 "%{buildroot}%{_datadir}/element/"
cp -lrv dist/linux-universal-unpacked/resources/* -t "%{buildroot}%{_datadir}/element/"
ln -vs %{_datadir}/webapps/element "%{buildroot}%{_datadir}/element/webapp"

# Install binaries to /usr/lib
install -vd -m 0755 "%{buildroot}%{_prefix}/lib/element/"
install -pvm0755 dist/linux-universal-unpacked/resources/app/node_modules/keytar/build/Release/keytar.node "%{buildroot}%{_prefix}/lib/element/keytar.node"
install -pvm0755 dist/linux-universal-unpacked/resources/app/node_modules/matrix-seshat/index.node "%{buildroot}%{_prefix}/lib/element/matrix-seshat.node"
ln -sfv "%{_prefix}/lib/element/keytar.node" "%{buildroot}%{_datadir}/element/app/node_modules/keytar/build/Release/keytar.node"
ln -sfv "%{_prefix}/lib/element/matrix-seshat.node" "%{buildroot}%{_datadir}/element/app/node_modules/matrix-seshat/index.node"

# Config file
install -vm 0755 -d %{buildroot}%{_sysconfdir}/element
install -pvm 0644 element.io/release/config.json "%{buildroot}%{_sysconfdir}/element/config.json"

install -pvm 0755 -d %{buildroot}%{_sysconfdir}/webapps/element
ln -vs %{_sysconfdir}/element/config.json "%{buildroot}%{_sysconfdir}/webapps/element/config.json"

install -vd -m 0755 "%{buildroot}%{_datadir}/webapps/element/"
ln -vs %{_sysconfdir}/element/config.json "%{buildroot}%{_datadir}/webapps/element/config.json" # moved here from element-web to make symlink check happy

# Required extras
install -vd -m 0755 "%{buildroot}%{_datadir}/applications/"
install -pvm 0644 %{SOURCE3} "%{buildroot}%{_datadir}/applications/io.element.Element.desktop"
install -vd -m 0755 "%{buildroot}%{_bindir}/"
install -pvm 0755 %{SOURCE4} "%{buildroot}%{_bindir}/%{name}"

# Icons
install -vd -m 0755 "%{buildroot}%{_datadir}/icons/hicolor/scalable/apps/"
for i in 16 24 48 64 96 128 256 512; do
	install -vd -m 0755 "%{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/"
	install -pvm 0644 build/icons/${i}x${i}.png "%{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/io.element.Element.png"
done

%fdupes %{buildroot}%{_datadir}

%check
%electron_check_native

%files
%license LICENSE
%{_bindir}/%{name}

%dir %{_datadir}/element/
%{_datadir}/element/webapp
%{_datadir}/element/app-update.yml
%dir %{_datadir}/element/app
%{_datadir}/element/app/lib
%{_datadir}/element/app/node_modules
%{_datadir}/element/app/package.json
%dir %{_datadir}/element/img
%{_datadir}/element/img/element.ico
%{_datadir}/element/img/element.png

%{_prefix}/lib/element/
%config(noreplace) %{_sysconfdir}/element/config.json
%{_sysconfdir}/webapps/element/config.json
%{_datadir}/webapps/element/config.json
%dir %{_sysconfdir}/element/
%{_datadir}/applications/io.element.Element.desktop
%{_datadir}/icons/hicolor/*/apps/io.element.Element.png

%changelog
* Fri Jun 21 2024 Dominik Heidler <dheidler@suse.de>
- Remove disable-spellchecker.patch as spellchecker is meanwhile
  configurable via Settings -> General
* Fri Jun 21 2024 Dominik Heidler <dheidler@suse.de>
- Disable dysfunctional spellchecker
  * disable-spellchecker.patch
* Tue Jun 18 2024 Dominik Heidler <dheidler@suse.com>
- Version 1.11.69
  [#]# ✨ Features
  * Change avatar setting component to use a menu (https://github.com/matrix-org/matrix-react-sdk/pull/12585). Contributed by @dbkr.
  * New user profile UI in User Settings (https://github.com/matrix-org/matrix-react-sdk/pull/12548). Contributed by @dbkr.
  * MSC4108 support OIDC QR code login (https://github.com/matrix-org/matrix-react-sdk/pull/12370). Contributed by @t3chguy.
  [#]# 🐛 Bug Fixes
  * Fix image upload preview size (https://github.com/matrix-org/matrix-react-sdk/pull/12612). Contributed by @RiotRobot.
  * Fix screen sharing in recent Chrome (https://github.com/matrix-org/matrix-js-sdk/pull/4243).
  * Fix roving tab index crash `compareDocumentPosition` (https://github.com/matrix-org/matrix-react-sdk/pull/12594). Contributed by @t3chguy.
  * Keep dialog glass border on narrow screens (https://github.com/matrix-org/matrix-react-sdk/pull/12591). Contributed by @dbkr.
  * Add missing a11y label to dismiss onboarding button in room list (https://github.com/matrix-org/matrix-react-sdk/pull/12587). Contributed by @t3chguy.
  * Add hover / active state on avatar setting upload button (https://github.com/matrix-org/matrix-react-sdk/pull/12590). Contributed by @dbkr.
  * Fix EditInPlace button styles (https://github.com/matrix-org/matrix-react-sdk/pull/12589). Contributed by @dbkr.
  * Fix incorrect assumptions about required fields in /search response (https://github.com/matrix-org/matrix-react-sdk/pull/12575). Contributed by @t3chguy.
  * Fix display of no avatar in avatar setting controls (https://github.com/matrix-org/matrix-react-sdk/pull/12558). Contributed by @dbkr.
  * Element-R: pass pickleKey in as raw key for indexeddb encryption (https://github.com/matrix-org/matrix-react-sdk/pull/12543). Contributed by @richvdh.
* Tue Jun  4 2024 Dominik Heidler <dheidler@suse.com>
- Version 1.11.68
  [#]# ✨ Features
  * Tooltip: Improve accessibility for  context menus (https://github.com/matrix-org/matrix-react-sdk/pull/12462). Contributed by @florianduros.
  * Tooltip: Improve accessibility of space panel (https://github.com/matrix-org/matrix-react-sdk/pull/12525). Contributed by @florianduros.
  [#]# 🐛 Bug Fixes
  * Close the release announcement when a dialog is opened (https://github.com/matrix-org/matrix-react-sdk/pull/12559). Contributed by @florianduros.
  * Tooltip: close field tooltip when ESC is pressed (https://github.com/matrix-org/matrix-react-sdk/pull/12553). Contributed by @florianduros.
  * Fix tabbedview breakpoint width (https://github.com/matrix-org/matrix-react-sdk/pull/12556). Contributed by @dbkr.
  * Fix E2E icon display in room header (https://github.com/matrix-org/matrix-react-sdk/pull/12545). Contributed by @florianduros.
  * Tooltip: Improve placement for space settings (https://github.com/matrix-org/matrix-react-sdk/pull/12541). Contributed by @florianduros.
  * Fix deformed avatar in a call in a narrow timeline (https://github.com/matrix-org/matrix-react-sdk/pull/12538). Contributed by @florianduros.
  * Shown own sent state indicator even when showReadReceipts is disabled (https://github.com/matrix-org/matrix-react-sdk/pull/12540). Contributed by @t3chguy.
  * Ensure we do not fire the verification mismatch modal multiple times (https://github.com/matrix-org/matrix-react-sdk/pull/12526). Contributed by @t3chguy.
  * Fix avatar in chat export (https://github.com/matrix-org/matrix-react-sdk/pull/12537). Contributed by @florianduros.
  * Use `*` for italics as it doesn't break when used mid-word (https://github.com/matrix-org/matrix-react-sdk/pull/12523). Contributed by @t3chguy.
* Wed May 22 2024 Dominik Heidler <dheidler@suse.de>
- Version 1.11.67
  [#]# ✨ Features
  * Tooltip: Improve the accessibility of the composer and the rich text editor (https://github.com/matrix-org/matrix-react-sdk/pull/12459). Contributed by @florianduros.
  * Allow explicit configuration of OIDC dynamic registration metadata (https://github.com/matrix-org/matrix-react-sdk/pull/12514). Contributed by @t3chguy.
  * Tooltip: improve accessibility for messages (https://github.com/matrix-org/matrix-react-sdk/pull/12487). Contributed by @florianduros.
  * Collapse UserSettings tabs to just icons on narrow screens (https://github.com/matrix-org/matrix-react-sdk/pull/12505). Contributed by @dbkr.
  * Add room topic to right panel room info (https://github.com/matrix-org/matrix-react-sdk/pull/12503). Contributed by @t3chguy.
  * OIDC: pass `id_token` via `id_token_hint` on Manage Account interaction (https://github.com/matrix-org/matrix-react-sdk/pull/12499). Contributed by @t3chguy.
  * Tooltip: improve accessibility in room (https://github.com/matrix-org/matrix-react-sdk/pull/12493). Contributed by @florianduros.
  * Tooltip: improve accessibility for call and voice messages (https://github.com/matrix-org/matrix-react-sdk/pull/12489). Contributed by @florianduros.
  * Move the active tab in user settings to the dialog title (https://github.com/matrix-org/matrix-react-sdk/pull/12481). Contributed by @dbkr.
  * Tooltip: improve accessibility of spaces (https://github.com/matrix-org/matrix-react-sdk/pull/12497). Contributed by @florianduros.
  * Tooltip: improve accessibility of the right panel (https://github.com/matrix-org/matrix-react-sdk/pull/12490). Contributed by @florianduros.
  * MSC3575 (Sliding Sync) add well-known proxy support (https://github.com/matrix-org/matrix-react-sdk/pull/12307). Contributed by @EdGeraghty.
  [#]# 🐛 Bug Fixes
  * Reuse single PlaybackWorker between Playback instances (https://github.com/matrix-org/matrix-react-sdk/pull/12520). Contributed by @t3chguy.
  * Fix well-known lookup for sliding sync labs check (https://github.com/matrix-org/matrix-react-sdk/pull/12519). Contributed by @t3chguy.
  * Fix `element-desktop-ssoid being` included in OIDC Authorization call (https://github.com/matrix-org/matrix-react-sdk/pull/12495). Contributed by @t3chguy.
  * Fix beta notifications reconciliation for intentional mentions push rules (https://github.com/matrix-org/matrix-react-sdk/pull/12510). Contributed by @t3chguy.
  * fix avatar stretched on 1:1 call (https://github.com/matrix-org/matrix-react-sdk/pull/12494). Contributed by @I-lander.
  * Check native sliding sync support against an unstable feature flag (https://github.com/matrix-org/matrix-react-sdk/pull/12498). Contributed by @turt2live.
  * Use OPTIONS for sliding sync detection poke (https://github.com/matrix-org/matrix-react-sdk/pull/12492). Contributed by @turt2live.
  * TAC: hide tooltip when the release announcement is displayed (https://github.com/matrix-org/matrix-react-sdk/pull/12472). Contributed by @florianduros.
  Version 1.11.66
  [#]# ✨ Features
  * Use a different error message for UTDs when you weren't in the room. (https://github.com/matrix-org/matrix-react-sdk/pull/12453). Contributed by @uhoreg.
  * Take the Threads Activity Centre out of labs (https://github.com/matrix-org/matrix-react-sdk/pull/12439). Contributed by @dbkr.
  * Expected UTDs: use a different message for UTDs sent before login (https://github.com/matrix-org/matrix-react-sdk/pull/12391). Contributed by @richvdh.
  * Add `Tooltip` to `AccessibleButton` (https://github.com/matrix-org/matrix-react-sdk/pull/12443). Contributed by @florianduros.
  * Add analytics to activity toggles (https://github.com/matrix-org/matrix-react-sdk/pull/12418). Contributed by @dbkr.
  * Decrypt events in reverse order without copying the array (https://github.com/matrix-org/matrix-react-sdk/pull/12445). Contributed by @Johennes.
  * Use new compound tooltip (https://github.com/matrix-org/matrix-react-sdk/pull/12416). Contributed by @florianduros.
  * Expected UTDs: report a different Posthog code (https://github.com/matrix-org/matrix-react-sdk/pull/12389). Contributed by @richvdh.
  [#]# 🐛 Bug Fixes
  * TAC: Fix accessibility issue when the Release announcement is displayed (https://github.com/matrix-org/matrix-react-sdk/pull/12484). Contributed by @RiotRobot.
  * TAC: Close Release Announcement when TAC button is clicked (https://github.com/matrix-org/matrix-react-sdk/pull/12485). Contributed by @florianduros.
  * MenuItem: fix caption usage (https://github.com/matrix-org/matrix-react-sdk/pull/12455). Contributed by @florianduros.
  * Show the local echo in previews (https://github.com/matrix-org/matrix-react-sdk/pull/12451). Contributed by @langleyd.
  * Fixed the drag and drop of X #27186 (https://github.com/matrix-org/matrix-react-sdk/pull/12450). Contributed by @asimdelvi.
  * Move the TAC to above the button (https://github.com/matrix-org/matrix-react-sdk/pull/12438). Contributed by @dbkr.
  * Use the same logic in previews as the timeline to hide events that should be hidden (https://github.com/matrix-org/matrix-react-sdk/pull/12434). Contributed by @langleyd.
  * Fix selector so maths support doesn't mangle divs (https://github.com/matrix-org/matrix-react-sdk/pull/12433). Contributed by @uhoreg.
* Fri May 17 2024 Dominik Heidler <dheidler@suse.de>
- Add mime handler required for native OIDC
* Thu May 16 2024 Bruno Pitrus <brunopitrus@hotmail.com>
- Use bundled sqlcipher to work around symbol collision through mozilla-nss
  (gh#sqlcipher/sqlcipher#385)
- Ship app unpacked instead of using asar
- Remove development-only files that should not be shipped (bsc#1224133)
- prepare.sh:
  * Ship dependencies as node_modules tree for patching possibility
    (yarn offline does not support patching)
  * Work around non-reproducible hakModules dependencies
    (gh#element-hq/element-desktop#1634) (hak-remove-devdependencies.patch)
  * Remove non-free binaries from archive
  * Remove vendored openssl copy from archive
  * Put everything into one archive
- Use correct CFLAGS and RUSTFLAGS
  * add cc-link-lib-no-static.patch
- Fix various build errors with electron-builder
  * 7za-path.patch
  * remove-fuses.patch
- BuildRequire app-builder instead of using a non-free binary
- Add standard Electron module load %%check
- Clean up unneeded BuildRequires
- Drop unused electron-web source copy
- Fix build error on ix86 and arm
- Fix unresolvable build on Fedora
* Tue Apr 23 2024 Dominik Heidler <dheidler@suse.de>
- Version 1.11.65
  [#]# ✨ Features
  * Make empty state copy for TAC depend on the value of the setting (https://github.com/matrix-org/matrix-react-sdk/pull/12419). Contributed by @dbkr.
  * Linkify User Interactive Authentication errors (https://github.com/matrix-org/matrix-react-sdk/pull/12271). Contributed by @t3chguy.
  * Add support for device dehydration v2 (https://github.com/matrix-org/matrix-react-sdk/pull/12316). Contributed by @uhoreg.
  * Replace `SecurityCustomisations` with `CryptoSetupExtension` (https://github.com/matrix-org/matrix-react-sdk/pull/12342). Contributed by @thoraj.
  * Add activity toggle for TAC (https://github.com/matrix-org/matrix-react-sdk/pull/12413). Contributed by @dbkr.
  * Humanize spell check language labels (https://github.com/matrix-org/matrix-react-sdk/pull/12409). Contributed by @t3chguy.
  * Call Guest Access, give user the option to change the acces level so they can generate a call link. (https://github.com/matrix-org/matrix-react-sdk/pull/12401). Contributed by @toger5.
  * TAC: Release Announcement (https://github.com/matrix-org/matrix-react-sdk/pull/12380). Contributed by @florianduros.
  * Show the call and share button if the user can create a guest link. (https://github.com/matrix-org/matrix-react-sdk/pull/12385). Contributed by @toger5.
  * Add analytics for mark all threads unread (https://github.com/matrix-org/matrix-react-sdk/pull/12384). Contributed by @dbkr.
  * Add `EventType.RoomEncryption` to the auto approve capabilities of Element Call widgets (https://github.com/matrix-org/matrix-react-sdk/pull/12386). Contributed by @toger5.
  [#]# 🐛 Bug Fixes
  * Fix link modal not shown after access upgrade (https://github.com/matrix-org/matrix-react-sdk/pull/12411). Contributed by @toger5.
  * Fix thread navigation in timeline (https://github.com/matrix-org/matrix-react-sdk/pull/12412). Contributed by @florianduros.
  * Fix inability to join a `knock` room via space hierarchy view (https://github.com/matrix-org/matrix-react-sdk/pull/12404). Contributed by @t3chguy.
  * Focus the thread panel when clicking on an item in the TAC (https://github.com/matrix-org/matrix-react-sdk/pull/12410). Contributed by @dbkr.
  * Fix space hierarchy tile busy state being stuck after join error (https://github.com/matrix-org/matrix-react-sdk/pull/12405). Contributed by @t3chguy.
  * Fix room topic in-app links not being handled correctly on topic dialog (https://github.com/matrix-org/matrix-react-sdk/pull/12406). Contributed by @t3chguy.
* Tue Apr  9 2024 Dominik Heidler <dheidler@suse.de>
- Version 1.11.64
  [#]# ✨ Features
  * Mark all threads as read button (https://github.com/matrix-org/matrix-react-sdk/pull/12378). Contributed by @dbkr.
  * Video call meta space (https://github.com/matrix-org/matrix-react-sdk/pull/12297). Contributed by @toger5.
  * Add leave room warning for last admin (https://github.com/matrix-org/matrix-react-sdk/pull/9452). Contributed by @Arnei.
  * Iterate styles around Link new device via QR (https://github.com/matrix-org/matrix-react-sdk/pull/12356). Contributed by @t3chguy.
  * Improve code-splitting of highlight.js and maplibre-gs libs (https://github.com/matrix-org/matrix-react-sdk/pull/12349). Contributed by @t3chguy.
  * Use data-mx-color for rainbows (https://github.com/matrix-org/matrix-react-sdk/pull/12325). Contributed by @tulir.
  [#]# 🐛 Bug Fixes
  * Fix external guest access url for unencrypted rooms (https://github.com/matrix-org/matrix-react-sdk/pull/12345). Contributed by @toger5.
  * Fix video rooms not showing share link button (https://github.com/matrix-org/matrix-react-sdk/pull/12374). Contributed by @toger5.
  * Fix space topic jumping on hover/focus (https://github.com/matrix-org/matrix-react-sdk/pull/12377). Contributed by @t3chguy.
  * Allow popping out a Jitsi widget to respect Desktop `web_base_url` config (https://github.com/matrix-org/matrix-react-sdk/pull/12376). Contributed by @t3chguy.
  * Remove the Lazy Loading `InvalidStoreError` Dialogs (https://github.com/matrix-org/matrix-react-sdk/pull/12358). Contributed by @langleyd.
  * Improve readability of badges and pills (https://github.com/matrix-org/matrix-react-sdk/pull/12360). Contributed by @robintown.
- Version 1.11.63
  This is a hotfix release to fix a couple of issues: one where the client would sometimes call the client/server API to set a push rule in a loop, and one where authentication was not sent for widgets when it should have been.
  [#]# 🐛 Bug Fixes
  * Revert "Make EC widget theme reactive - Update widget url when the theme changes" (https://github.com/matrix-org/matrix-react-sdk/pull/12383) in order to fix widgets that require authentication.
  * Update to hotfixed js-sdk to fix an issue where Element could try to set a push rule in a loop.
- Version 1.11.62
  [#]# ✨ Features
  * Change user permission by using a new apply button (https://github.com/matrix-org/matrix-react-sdk/pull/12346). Contributed by @florianduros.
  * Mark as Unread (https://github.com/matrix-org/matrix-react-sdk/pull/12254). Contributed by @dbkr.
  * Refine the colors of some more components (https://github.com/matrix-org/matrix-react-sdk/pull/12343). Contributed by @robintown.
  * TAC: Order rooms by most recent after notification level (https://github.com/matrix-org/matrix-react-sdk/pull/12329). Contributed by @florianduros.
  * Make EC widget theme reactive - Update widget url when the theme changes (https://github.com/matrix-org/matrix-react-sdk/pull/12295). Contributed by @toger5.
  * Refine styles of menus, toasts, popovers, and modals (https://github.com/matrix-org/matrix-react-sdk/pull/12332). Contributed by @robintown.
  * Element Call: fix widget shown while its still loading (`waitForIframeLoad=false`) (https://github.com/matrix-org/matrix-react-sdk/pull/12292). Contributed by @toger5.
  * Improve Forward Dialog a11y by switching to roving tab index interactions (https://github.com/matrix-org/matrix-react-sdk/pull/12306). Contributed by @t3chguy.
  * Call guest access link creation to join calls as a non registered user via the EC SPA (https://github.com/matrix-org/matrix-react-sdk/pull/12259). Contributed by @toger5.
  * Use `strong` element to semantically denote visually emphasised content (https://github.com/matrix-org/matrix-react-sdk/pull/12320). Contributed by @t3chguy.
  * Handle up/down arrow keys as well as left/right for horizontal toolbars for improved a11y (https://github.com/matrix-org/matrix-react-sdk/pull/12305). Contributed by @t3chguy.
  [#]# 🐛 Bug Fixes
  * https://github.com/matrix-org/matrix-react-sdk/pull/12369). Contributed by @RiotRobot.
  * Fix incorrect check for private read receipt support (https://github.com/matrix-org/matrix-react-sdk/pull/12348). Contributed by @tulir.
  * TAC: Fix hover state when expanded (https://github.com/matrix-org/matrix-react-sdk/pull/12337). Contributed by @florianduros.
  * Fix the image view (https://github.com/matrix-org/matrix-react-sdk/pull/12341). Contributed by @robintown.
  * Use correct push rule to evaluate room-wide mentions (https://github.com/matrix-org/matrix-react-sdk/pull/12318). Contributed by @t3chguy.
  * Reset power selector on API failure to prevent state mismatch (https://github.com/matrix-org/matrix-react-sdk/pull/12319). Contributed by @t3chguy.
  * Fix spotlight opening in TAC (https://github.com/matrix-org/matrix-react-sdk/pull/12315). Contributed by @florianduros.
* Thu Mar 14 2024 Dominik Heidler <dheidler@suse.de>
- Version 1.11.61
  * No changes
  [#]# 🐛 Bug Fixes
  * Update `@vector-im/compound-design-tokens` in package.json (https://github.com/matrix-org/matrix-react-sdk/pull/12340).
* Wed Mar 13 2024 Dominik Heidler <dheidler@suse.de>
- Version 1.11.60
  [#]# ✨ Features
  * Refine styles of controls to match Compound (https://github.com/matrix-org/matrix-react-sdk/pull/12299). Contributed by @robintown.
  * Hide the archived section (https://github.com/matrix-org/matrix-react-sdk/pull/12286). Contributed by @dbkr.
  * Add theme data to EC widget Url (https://github.com/matrix-org/matrix-react-sdk/pull/12279). Contributed by @toger5.
  * Update MSC2965 OIDC Discovery implementation (https://github.com/matrix-org/matrix-react-sdk/pull/12245). Contributed by @t3chguy.
  * Use green dot for activity notification in `LegacyRoomHeader` (https://github.com/matrix-org/matrix-react-sdk/pull/12270). Contributed by @florianduros.
  [#]# 🐛 Bug Fixes
  * Fix requests for senders to submit auto-rageshakes (https://github.com/matrix-org/matrix-react-sdk/pull/12304). Contributed by @richvdh.
  * fix automatic DM avatar with functional members (https://github.com/matrix-org/matrix-react-sdk/pull/12157). Contributed by @HarHarLinks.
  * Feeds event with relation to unknown to the widget (https://github.com/matrix-org/matrix-react-sdk/pull/12283). Contributed by @maheichyk.
  * Fix TAC opening with keyboard (https://github.com/matrix-org/matrix-react-sdk/pull/12285). Contributed by @florianduros.
  * Allow screenshot update docker to run multiple test files (https://github.com/matrix-org/matrix-react-sdk/pull/12291). Contributed by @dbkr.
  * Fix alignment of user menu avatar (https://github.com/matrix-org/matrix-react-sdk/pull/12289). Contributed by @dbkr.
  * Fix buttons of widget in a room (https://github.com/matrix-org/matrix-react-sdk/pull/12288). Contributed by @florianduros.
  * ModuleAPI: `overwrite_login` action was not stopping the existing client resulting in the action failing with rust-sdk (https://github.com/matrix-org/matrix-react-sdk/pull/12272). Contributed by @BillCarsonFr.
- Version 1.11.59
  [#]# 🦖 Deprecations
  * Enable custom themes to theme Compound (https://github.com/matrix-org/matrix-react-sdk/pull/12240). Contributed by @robintown.
  * Remove welcome bot `welcome_user_id` support (https://github.com/matrix-org/matrix-react-sdk/pull/12153). Contributed by @t3chguy.
  [#]# ✨ Features
  * Ignore activity in TAC (https://github.com/matrix-org/matrix-react-sdk/pull/12269). Contributed by @florianduros.
  * Use browser's font size instead of hardcoded `16px` as root font size (https://github.com/matrix-org/matrix-react-sdk/pull/12246). Contributed by @florianduros.
  * Revert "Use Compound primary colors for most actions" (https://github.com/matrix-org/matrix-react-sdk/pull/12264). Contributed by @florianduros.
  * Revert "Refine menu, toast, and popover colors" (https://github.com/matrix-org/matrix-react-sdk/pull/12263). Contributed by @florianduros.
  * Fix Native OIDC for Element Desktop (https://github.com/matrix-org/matrix-react-sdk/pull/12253). Contributed by @t3chguy.
  * Improve client metadata used for OIDC dynamic registration (https://github.com/matrix-org/matrix-react-sdk/pull/12257). Contributed by @t3chguy.
  * Refine menu, toast, and popover colors (https://github.com/matrix-org/matrix-react-sdk/pull/12247). Contributed by @robintown.
  * Call the AsJson forms of import and exportRoomKeys (https://github.com/matrix-org/matrix-react-sdk/pull/12233). Contributed by @andybalaam.
  * Use Compound primary colors for most actions (https://github.com/matrix-org/matrix-react-sdk/pull/12241). Contributed by @robintown.
  * Enable redirected media by default (https://github.com/matrix-org/matrix-react-sdk/pull/12142). Contributed by @turt2live.
  * Reduce TAC width by `16px` (https://github.com/matrix-org/matrix-react-sdk/pull/12239). Contributed by @florianduros.
  * Pop out of Threads Activity Centre (https://github.com/matrix-org/matrix-react-sdk/pull/12136). Contributed by @florianduros.
  * Use new semantic tokens for username colors (https://github.com/matrix-org/matrix-react-sdk/pull/12209). Contributed by @robintown.
  [#]# 🐛 Bug Fixes
  * Fix the space panel getting bigger when gaining a scroll bar (https://github.com/matrix-org/matrix-react-sdk/pull/12267). Contributed by @dbkr.
  * Fix gradients spacings on the space panel (https://github.com/matrix-org/matrix-react-sdk/pull/12262). Contributed by @dbkr.
  * Remove hardcoded `Element` in tac labs description (https://github.com/matrix-org/matrix-react-sdk/pull/12266). Contributed by @florianduros.
  * Fix branding in "migrating crypto" message (https://github.com/matrix-org/matrix-react-sdk/pull/12265). Contributed by @richvdh.
  * Use h1 as first heading in dialogs (https://github.com/matrix-org/matrix-react-sdk/pull/12250). Contributed by @dbkr.
  * Fix forced lowercase username in login/registration flows (https://github.com/matrix-org/matrix-react-sdk/pull/9329). Contributed by @vrifox.
  * Update the TAC indicator on event decryption (https://github.com/matrix-org/matrix-react-sdk/pull/12243). Contributed by @dbkr.
  * Fix OIDC delegated auth account url check (https://github.com/matrix-org/matrix-react-sdk/pull/12242). Contributed by @t3chguy.
  * New Header edgecase fixes: Close lobby button not shown, disable join button in various places, more... (https://github.com/matrix-org/matrix-react-sdk/pull/12235). Contributed by @toger5.
  * Fix TAC button alignment when expanded (https://github.com/matrix-org/matrix-react-sdk/pull/12238). Contributed by @florianduros.
  * Fix tooltip behaviour in TAC (https://github.com/matrix-org/matrix-react-sdk/pull/12236). Contributed by @florianduros.
* Wed Feb 14 2024 Dominik Heidler <dheidler@suse.de>
- Version 1.11.58
  * 🦀  🔒 **The flag to enable the Rust crypto implementation is now set to `true` by default. This means that without any additional configuration every new login will use the new cryptography implementation.**
  * Add Element call related functionality to new room header (https://github.com/matrix-org/matrix-react-sdk/pull/12091). Contributed by @toger5.
  * Add labs flag for Threads Activity Centre (https://github.com/matrix-org/matrix-react-sdk/pull/12137). Contributed by @florianduros.
  * Refactor element call lobby + skip lobby (https://github.com/matrix-org/matrix-react-sdk/pull/12057). Contributed by @toger5.
  * Hide the "Message" button in the sidebar if the CreateRooms components should not be shown (https://github.com/matrix-org/matrix-react-sdk/pull/9271). Contributed by @dhenneke.
  * Add notification dots to thread summary icons (https://github.com/matrix-org/matrix-react-sdk/pull/12146). Contributed by @dbkr.
  [#]# 🐛 Bug Fixes
  * Fix logout can take ages (https://github.com/matrix-org/matrix-react-sdk/pull/12191). Contributed by @BillCarsonFr.
  * Fix `Mark all as read` in settings (https://github.com/matrix-org/matrix-react-sdk/pull/12205). Contributed by @florianduros.
  * Fix default thread notification of the new RoomHeader (https://github.com/matrix-org/matrix-react-sdk/pull/12194). Contributed by @florianduros.
  * Fix display of room notification debug info (https://github.com/matrix-org/matrix-react-sdk/pull/12183). Contributed by @dbkr.
* Thu Feb  1 2024 Dominik Heidler <dheidler@suse.de>
- Version 1.11.57
  [#]# 🦖 Deprecations
  * Deprecate welcome bot `welcome_user_id` support (https://github.com/element-hq/element-web/pull/26885). Contributed by @t3chguy.
  [#]# 🦖 Deprecations
  * Deprecate welcome bot `welcome_user_id` support (https://github.com/element-hq/element-web/pull/26885). Contributed by @t3chguy.
  [#]# ✨ Features
  * Use jitsi-lobby in video channel (video rooms) (https://github.com/element-hq/element-web/pull/26879). Contributed by @toger5.
  [#]# 🐛 Bug Fixes
  * Fix OIDC bugs due to amnesiac stores forgetting OIDC issuer \& other data (https://github.com/matrix-org/matrix-react-sdk/pull/12166). Contributed by @t3chguy.
  * Fix account management link for delegated auth OIDC setups (https://github.com/matrix-org/matrix-react-sdk/pull/12144). Contributed by @t3chguy.
  * Fix Safari IME support (https://github.com/matrix-org/matrix-react-sdk/pull/11016). Contributed by @SuperKenVery.
  * Fix Stickerpicker layout crossing multiple CSS stacking contexts (https://github.com/matrix-org/matrix-react-sdk/pull/12127).
  * Fix Stickerpicker layout crossing multiple CSS stacking contexts (https://github.com/matrix-org/matrix-react-sdk/pull/12126). Contributed by @t3chguy.
  * Fix 1F97A and 1F979 in Twemoji COLR font (https://github.com/matrix-org/matrix-react-sdk/pull/12177).
  [#]# ✨ Features
  * Use jitsi-lobby in video channel (video rooms) (https://github.com/element-hq/element-web/pull/26879). Contributed by @toger5.
  [#]# 🐛 Bug Fixes
  * Fix OIDC bugs due to amnesiac stores forgetting OIDC issuer \& other data (https://github.com/matrix-org/matrix-react-sdk/pull/12166). Contributed by @t3chguy.
  * Fix account management link for delegated auth OIDC setups (https://github.com/matrix-org/matrix-react-sdk/pull/12144). Contributed by @t3chguy.
  * Fix Safari IME support (https://github.com/matrix-org/matrix-react-sdk/pull/11016). Contributed by @SuperKenVery.
  * Fix Stickerpicker layout crossing multiple CSS stacking contexts (https://github.com/matrix-org/matrix-react-sdk/pull/12127).
  * Fix Stickerpicker layout crossing multiple CSS stacking contexts (https://github.com/matrix-org/matrix-react-sdk/pull/12126). Contributed by @t3chguy.
  * Fix 1F97A and 1F979 in Twemoji COLR font (https://github.com/matrix-org/matrix-react-sdk/pull/12177).
* Thu Jan 18 2024 Dominik Heidler <dheidler@suse.de>
- Repackage app.asar analog to pre-1.11.54 to get native features working again
* Wed Jan 17 2024 Dominik Heidler <dheidler@suse.de>
- Version 1.11.54
  [#]# 🔧 Security
  * Burn Node-related Electron fuses as a proactive hardening measure (https://github.com/element-hq/element-desktop/pull/1412). Contributed by @t3chguy.
  [#]# ✨ Features
  * Accessibility improvements around aria-labels and tooltips (https://github.com/matrix-org/matrix-react-sdk/pull/12062). Contributed by @t3chguy.
  * Add RoomKnocksBar to RoomHeader (https://github.com/matrix-org/matrix-react-sdk/pull/12077). Contributed by @charlynguyen.
  * Adjust tooltip side for DecoratedRoomAvatar to not obscure room name (https://github.com/matrix-org/matrix-react-sdk/pull/12079). Contributed by @t3chguy.
  * Iterate landmarks around the app in order to improve a11y (https://github.com/matrix-org/matrix-react-sdk/pull/12064). Contributed by @t3chguy.
  * Update element call embedding UI (https://github.com/matrix-org/matrix-react-sdk/pull/12056). Contributed by @toger5.
  * Use Compound tooltips instead of homegrown in TextWithTooltip \& InfoTooltip (https://github.com/matrix-org/matrix-react-sdk/pull/12052). Contributed by @t3chguy.
  [#]# 🐛 Bug Fixes
  * Fix regression around CSS stacking contexts and PIP widgets (https://github.com/matrix-org/matrix-react-sdk/pull/12094). Contributed by @t3chguy.
  * Fix Identity Server terms accepting not working as expected (https://github.com/matrix-org/matrix-react-sdk/pull/12109). Contributed by @t3chguy.
  * fix: microphone and camera dropdown doesn't work In legacy call (https://github.com/matrix-org/matrix-react-sdk/pull/12105). Contributed by @muratersin.
  * Revert "Set up key backup using non-deprecated APIs (#12005)" (https://github.com/matrix-org/matrix-react-sdk/pull/12102). Contributed by @BillCarsonFr.
  * Fix regression around read receipt animation from refs changes (https://github.com/matrix-org/matrix-react-sdk/pull/12100). Contributed by @t3chguy.
  * Added meaning full error message based on platform (https://github.com/matrix-org/matrix-react-sdk/pull/12074). Contributed by @Pankaj-SinghR.
  * Fix editing event from search room view (https://github.com/matrix-org/matrix-react-sdk/pull/11992). Contributed by @t3chguy.
  * Fix timeline position when moving to a room and coming back (https://github.com/matrix-org/matrix-react-sdk/pull/12055). Contributed by @florianduros.
  * Fix threaded reply playwright tests (https://github.com/matrix-org/matrix-react-sdk/pull/12070). Contributed by @dbkr.
  * Element-R: fix repeated requests to enter 4S key during cross-signing reset (https://github.com/matrix-org/matrix-react-sdk/pull/12059). Contributed by @richvdh.
  * Fix position of thumbnail in room timeline (https://github.com/matrix-org/matrix-react-sdk/pull/12016). Contributed by @anoopw3bdev.
* Thu Jan  4 2024 Dominik Heidler <dheidler@suse.de>
- Version 1.11.53
  [#]# 🐛 Bug Fixes
  * Fix a fresh login creating a new key backup (https://github.com/matrix-org/matrix-react-sdk/pull/12106).
* Tue Dec 19 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.52
  [#]# ✨ Features
  * Keep more recent rageshake logs (https://github.com/matrix-org/matrix-react-sdk/pull/12003). Contributed by @richvdh.
  [#]# 🐛 Bug Fixes
  * Fix bug which prevented correct clean up of rageshake store (https://github.com/matrix-org/matrix-react-sdk/pull/12002). Contributed by @richvdh.
  * Set up key backup using non-deprecated APIs (https://github.com/matrix-org/matrix-react-sdk/pull/12005). Contributed by @andybalaam.
  * Fix notifications appearing for old events (https://github.com/matrix-org/matrix-js-sdk/pull/3946). Contributed by @dbkr.
  * Prevent phantom notifications from events not in a room's timeline (https://github.com/matrix-org/matrix-js-sdk/pull/3942). Contributed by @dbkr.
* Wed Dec  6 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.51
  [#]# 🦖 Deprecations
  * Remove Quote from MessageContextMenu as it is unsupported by WYSIWYG (https://github.com/matrix-org/matrix-react-sdk/pull/11914). Contributed by @t3chguy.
  [#]# ✨ Features
  * Always allow call.member events on new rooms (https://github.com/matrix-org/matrix-react-sdk/pull/11948). Contributed by @toger5.
  * Right panel: view third party invite info without clearing history (https://github.com/matrix-org/matrix-react-sdk/pull/11934). Contributed by @kerryarchibald.
  * Allow switching to system emoji font (https://github.com/matrix-org/matrix-react-sdk/pull/11925). Contributed by @t3chguy.
  * Update open in other tab message (https://github.com/matrix-org/matrix-react-sdk/pull/11916). Contributed by @weeman1337.
  * Add menu for legacy and element call in 1:1 rooms (https://github.com/matrix-org/matrix-react-sdk/pull/11910). Contributed by @toger5.
  * Add ringing for matrixRTC (https://github.com/matrix-org/matrix-react-sdk/pull/11870). Contributed by @toger5.
  [#]# 🐛 Bug Fixes
  * Keep device language when it has been previosuly set, after a successful delegated authentication flow that clears localStorage (https://github.com/matrix-org/matrix-react-sdk/pull/11902). Contributed by @mgcm.
  * Fix misunderstanding of functional members (https://github.com/matrix-org/matrix-react-sdk/pull/11918). Contributed by @toger5.
  * Fix: Video Room Chat Header Button Removed (https://github.com/matrix-org/matrix-react-sdk/pull/11911). Contributed by @kerryarchibald.
  * Fix "not attempting encryption" warning (https://github.com/matrix-org/matrix-react-sdk/pull/11899). Contributed by @richvdh.
* Tue Nov 21 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.50
* Mon Nov 13 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.49
  [#]# 🐛 Bug Fixes
  * Ensure `setUserCreator` is called when a store is assigned (https://github.com/matrix-org/matrix-js-sdk/pull/3867). Fixes vector-im/element-web#26520. Contributed by @MidhunSureshR.
* Tue Nov  7 2023 Dominik Heidler <dheidler@suse.de>
- - Version 1.11.48
  [#]# ✨ Features
  * Correctly fill window.matrixChat even when a Wrapper module is active (https://github.com/vector-im/element-web/pull/26395). Contributed by @dhenneke.
  * Knock on a ask-to-join room if a module wants to join the room when navigating to a room (https://github.com/matrix-org/matrix-react-sdk/pull/11787). Contributed by @dhenneke.
  * Element-R:  Include crypto info in sentry (https://github.com/matrix-org/matrix-react-sdk/pull/11798). Contributed by @florianduros.
  * Element-R:  Include crypto info in rageshake (https://github.com/matrix-org/matrix-react-sdk/pull/11797). Contributed by @florianduros.
  * Element-R: Add current version of the rust-sdk and vodozemac (https://github.com/matrix-org/matrix-react-sdk/pull/11785). Contributed by @florianduros.
  * Fix unfederated invite dialog (https://github.com/matrix-org/matrix-react-sdk/pull/9618). Fixes vector-im/element-meta#1466 and vector-im/element-web#22102. Contributed by @owi92.
  * New right panel visual language (https://github.com/matrix-org/matrix-react-sdk/pull/11664).
  * OIDC: add friendly errors (https://github.com/matrix-org/matrix-react-sdk/pull/11184). Fixes vector-im/element-web#25665. Contributed by @kerryarchibald.
  [#]# 🐛 Bug Fixes
  * Fix rightpanel hiding scrollbar (https://github.com/matrix-org/matrix-react-sdk/pull/11831). Contributed by @kerryarchibald.
  * Fix edge cases around macos draggability (https://github.com/vector-im/element-desktop/pull/1291). Fixes #1290.
  * Fix multi-tab session lock on Firefox not being cleared (https://github.com/matrix-org/matrix-react-sdk/pull/11800). Fixes vector-im/element-web#26165. Contributed by @ManuelHu.
  * Deserialise spoilers back into slash command form (https://github.com/matrix-org/matrix-react-sdk/pull/11805). Fixes vector-im/element-web#26344.
  * Fix Incorrect message scaling for verification request (https://github.com/matrix-org/matrix-react-sdk/pull/11793). Fixes vector-im/element-web#24304. Contributed by @capGoblin.
  * Fix: Unable to restore a soft-logged-out session established via SSO (https://github.com/matrix-org/matrix-react-sdk/pull/11794). Fixes vector-im/element-web#25957. Contributed by @kerryarchibald.
  * Use configurable github issue links more consistently (https://github.com/matrix-org/matrix-react-sdk/pull/11796).
  * Fix io.element.late_event received_ts vs received_at (https://github.com/matrix-org/matrix-react-sdk/pull/11789).
  * Make invitation dialog scrollable when infos are too long (https://github.com/matrix-org/matrix-react-sdk/pull/11753). Contributed by @nurjinjafar.
  * Fix spoiler text-align (https://github.com/matrix-org/matrix-react-sdk/pull/11790). Contributed by @ajbura.
  * Fix: Right panel keeps showing chat when unmaximizing widget.  (https://github.com/matrix-org/matrix-react-sdk/pull/11697). Fixes vector-im/element-web#26265. Contributed by @manancodes.
  * Fix margin of invite to room button (https://github.com/matrix-org/matrix-react-sdk/pull/11780). Fixes vector-im/element-web#26410.
  * Update base64 import (https://github.com/matrix-org/matrix-react-sdk/pull/11784).
  * Set max size for Element logo in search warning (https://github.com/matrix-org/matrix-react-sdk/pull/11779). Fixes vector-im/element-web#26408.
  * Fix: emoji size in room header topic, remove obsolete emoji style (https://github.com/matrix-org/matrix-react-sdk/pull/11757). Fixes vector-im/element-web#26326. Contributed by @kerryarchibald.
  * Fix: Bubble layout design is broken (https://github.com/matrix-org/matrix-react-sdk/pull/11763). Fixes vector-im/element-web#25818. Contributed by @manancodes.
* Thu Nov  2 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.47
  [#]# ✨ Features
  * Allow overwriting app.element.io when popping out widgets ([\#1277](https://github.com/vector-im/element-desktop/pull/1277)). Fixes #1187.
  * Implement macos title bar negative space ([\#1272](https://github.com/vector-im/element-desktop/pull/1272)). Fixes #1245.
  * vector-im/element-x-ios/issues/1824 - Convert the apple-app-site-association file to a newer format… ([\#26307](https://github.com/vector-im/element-web/pull/26307)). Contributed by @stefanceriu.
  * Iterate `io.element.late_event` decoration ([\#11760](https://github.com/matrix-org/matrix-react-sdk/pull/11760)). Fixes vector-im/element-web#26384.
  * Render timeline separator for late event groups ([\#11739](https://github.com/matrix-org/matrix-react-sdk/pull/11739)).
  * OIDC: revoke tokens on logout ([\#11718](https://github.com/matrix-org/matrix-react-sdk/pull/11718)). Fixes vector-im/element-web#25394. Contributed by @kerryarchibald.
  * Show `io.element.late_event` in MessageTimestamp when known ([\#11733](https://github.com/matrix-org/matrix-react-sdk/pull/11733)).
  * Show all labs flags if developerMode enabled ([\#11746](https://github.com/matrix-org/matrix-react-sdk/pull/11746)). Fixes vector-im/element-web#24571 and vector-im/element-web#8498.
  * Use Compound tooltips on MessageTimestamp to improve UX of date time discovery ([\#11732](https://github.com/matrix-org/matrix-react-sdk/pull/11732)). Fixes vector-im/element-web#25913.
  * Consolidate 4s passphrase input fields and use stable IDs ([\#11743](https://github.com/matrix-org/matrix-react-sdk/pull/11743)). Fixes vector-im/element-web#26228.
  * Disable upgraderoom command without developer mode enabled ([\#11744](https://github.com/matrix-org/matrix-react-sdk/pull/11744)). Fixes vector-im/element-web#17620.
  * Avoid rendering app download buttons if disabled in config ([\#11741](https://github.com/matrix-org/matrix-react-sdk/pull/11741)). Fixes vector-im/element-web#26309.
  * OIDC: refresh tokens ([\#11699](https://github.com/matrix-org/matrix-react-sdk/pull/11699)). Fixes vector-im/element-web#25839. Contributed by @kerryarchibald.
  * OIDC: register ([\#11727](https://github.com/matrix-org/matrix-react-sdk/pull/11727)). Fixes vector-im/element-web#25393. Contributed by @kerryarchibald.
  * Use stable get_login_token and remove unstable MSC3882 support ([\#11001](https://github.com/matrix-org/matrix-react-sdk/pull/11001)). Contributed by @hughns.
  [#]# 🐛 Bug Fixes
  * Set max size for Element logo in search warning ([\#11779](https://github.com/matrix-org/matrix-react-sdk/pull/11779)). Fixes vector-im/element-web#26408.
  * Avoid error when DMing oneself ([\#11754](https://github.com/matrix-org/matrix-react-sdk/pull/11754)). Fixes vector-im/element-web#7242.
  * Fix: Message shield alignment is not right. ([\#11703](https://github.com/matrix-org/matrix-react-sdk/pull/11703)). Fixes vector-im/element-web#26142. Contributed by @manancodes.
  * fix logging full event ([\#11755](https://github.com/matrix-org/matrix-react-sdk/pull/11755)). Fixes vector-im/element-web#26376.
  * OIDC: use delegated auth account URL from `OidcClientStore` ([\#11723](https://github.com/matrix-org/matrix-react-sdk/pull/11723)). Fixes vector-im/element-web#26305. Contributed by @kerryarchibald.
  * Fix: Members list shield alignment is not right. ([\#11700](https://github.com/matrix-org/matrix-react-sdk/pull/11700)). Fixes vector-im/element-web#26261. Contributed by @manancodes.
  * Fix: <detail> HTML elements clickable area too wide. ([\#11666](https://github.com/matrix-org/matrix-react-sdk/pull/11666)). Fixes vector-im/element-web#25454. Contributed by @manancodes.
  * Fix untranslated headings in the devtools dialog ([\#11734](https://github.com/matrix-org/matrix-react-sdk/pull/11734)).
  * Fixes invite dialog alignment and pill color contrast ([\#11722](https://github.com/matrix-org/matrix-react-sdk/pull/11722)). Contributed by @gabrc52.
  * Prevent select element in General settings overflowing in a room with very long room-id ([\#11597](https://github.com/matrix-org/matrix-react-sdk/pull/11597)). Contributed by @ABHIXIT2.
  * Fix: Clicking on members pile does nothing. ([\#11657](https://github.com/matrix-org/matrix-react-sdk/pull/11657)). Fixes vector-im/element-web#26164. Contributed by @manancodes.
  * Fix: Wierd shadow below room avatar in dark mode. ([\#11678](https://github.com/matrix-org/matrix-react-sdk/pull/11678)). Fixes vector-im/element-web#26153. Contributed by @manancodes.
  * Fix start_sso / start_cas URLs failing to redirect to a authentication prompt ([\#11681](https://github.com/matrix-org/matrix-react-sdk/pull/11681)). Contributed by @Half-Shot.
- Version 1.11.46
  [#]# ✨ Features
  * Use .well-known to discover a default rendezvous server for use with Sign in with QR ([\#11655](https://github.com/matrix-org/matrix-react-sdk/pull/11655)). Contributed by @hughns.
  * Message layout will update according to the selected style  ([\#10170](https://github.com/matrix-org/matrix-react-sdk/pull/10170)). Fixes vector-im/element-web#21782. Contributed by @manancodes.
  * Implement MSC4039: Add an MSC for a new Widget API action to upload files into the media repository ([\#11311](https://github.com/matrix-org/matrix-react-sdk/pull/11311)). Contributed by @dhenneke.
  * Render space pills with square corners to match new avatar ([\#11632](https://github.com/matrix-org/matrix-react-sdk/pull/11632)). Fixes vector-im/element-web#26056.
  * Linkify room topic ([\#11631](https://github.com/matrix-org/matrix-react-sdk/pull/11631)). Fixes vector-im/element-web#26185.
  * Show knock rooms in the list ([\#11573](https://github.com/matrix-org/matrix-react-sdk/pull/11573)). Contributed by @maheichyk.
  [#]# 🐛 Bug Fixes
  * Bump matrix-web-i18n dependency to 3.1.3 ([\#1259](https://github.com/vector-im/element-desktop/pull/1259) and [\#26287](https://github.com/vector-im/element-web/pull/26287))
  * Fix: Avatar shrinks with long names ([\#11698](https://github.com/matrix-org/matrix-react-sdk/pull/11698)). Fixes vector-im/element-web#26252. Contributed by @manancodes.
  * Update custom translations to support nested fields in structured JSON ([\#11685](https://github.com/matrix-org/matrix-react-sdk/pull/11685)).
  * Fix: Edited message remove button is hard to reach. ([\#11674](https://github.com/matrix-org/matrix-react-sdk/pull/11674)). Fixes vector-im/element-web#24917. Contributed by @manancodes.
  * Fix: Theme selector radio button not aligned in center with the text ([\#11676](https://github.com/matrix-org/matrix-react-sdk/pull/11676)). Fixes vector-im/element-web#25460. Contributed by @manancodes.
  * Fix: Unread notification dot aligned ([\#11658](https://github.com/matrix-org/matrix-react-sdk/pull/11658)). Fixes vector-im/element-web#25285. Contributed by @manancodes.
  * Fix: sync intentional mentions push rules with legacy rules ([\#11667](https://github.com/matrix-org/matrix-react-sdk/pull/11667)). Fixes vector-im/element-web#26227. Contributed by @kerryarchibald.
  * Revert "Fix regression around FacePile with overflow (#11527)" ([\#11634](https://github.com/matrix-org/matrix-react-sdk/pull/11634)). Fixes vector-im/element-web#26209.
  * Fix: Alignment Fixed ([\#11648](https://github.com/matrix-org/matrix-react-sdk/pull/11648)). Fixes vector-im/element-web#26169. Contributed by @manancodes.
  * Fix: onFinished added which closes the menu ([\#11647](https://github.com/matrix-org/matrix-react-sdk/pull/11647)). Fixes vector-im/element-web#25556. Contributed by @manancodes.
  * Don't start key backups when opening settings ([\#11640](https://github.com/matrix-org/matrix-react-sdk/pull/11640)).
  * Fix add to space avatar text centering ([\#11643](https://github.com/matrix-org/matrix-react-sdk/pull/11643)). Fixes vector-im/element-web#26154.
  * fix avatar styling in lightbox ([\#11641](https://github.com/matrix-org/matrix-react-sdk/pull/11641)). Fixes vector-im/element-web#26196.
- Version 1.11.45
  [#]# 🔒 Security
  * Upgrade electron to 26.2.4 to fix CVE-2023-5217 ([\#1254](https://github.com/vector-im/element-desktop/pull/1254)). Contributed by @andybalaam.
  [#]# 🐛 Bug Fixes
  * Fix Emoji font on Safari 17 ([\#11673](https://github.com/matrix-org/matrix-react-sdk/pull/11673)).
- Version 1.11.44
  [#]# ✨ Features
  * Make video & voice call buttons pin conference widget if unpinned ([\#11576](https://github.com/matrix-org/matrix-react-sdk/pull/11576)). Fixes vector-im/customer-retainer#72.
  * OIDC: persist refresh token ([\#11249](https://github.com/matrix-org/matrix-react-sdk/pull/11249)). Contributed by @kerryarchibald.
  * ElementR: Cross user verification ([\#11364](https://github.com/matrix-org/matrix-react-sdk/pull/11364)). Fixes vector-im/element-web#25752. Contributed by @florianduros.
  * Default intentional mentions ([\#11602](https://github.com/matrix-org/matrix-react-sdk/pull/11602)).
  * Notify users about denied access on ask-to-join  rooms ([\#11480](https://github.com/matrix-org/matrix-react-sdk/pull/11480)). Contributed by @nurjinjafar.
  * Allow setting knock room directory visibility ([\#11529](https://github.com/matrix-org/matrix-react-sdk/pull/11529)). Contributed by @charlynguyen.
  [#]# 🐛 Bug Fixes
  * Revert "Fix regression around FacePile with overflow (#11527)" ([\#11634](https://github.com/matrix-org/matrix-react-sdk/pull/11634)). Fixes vector-im/element-web#26209.
  * upgrade electron to 26.2.1 to fix CVE-2023-4863 ([\#1226](https://github.com/vector-im/element-desktop/pull/1226)). Contributed by @selfisekai.
  * Improve edge cases around macOS drag handles ([\#1219](https://github.com/vector-im/element-desktop/pull/1219)). Fixes #1199 and #1188.
  * Escape placeholder before injecting it into the style ([\#11607](https://github.com/matrix-org/matrix-react-sdk/pull/11607)).
  * Move ViewUser action callback to RoomView ([\#11495](https://github.com/matrix-org/matrix-react-sdk/pull/11495)). Fixes vector-im/element-web#26040.
  * Fix room timeline search toggling behaviour edge case ([\#11605](https://github.com/matrix-org/matrix-react-sdk/pull/11605)). Fixes vector-im/element-web#26105.
  * Avoid rendering view-message link in RoomKnocksBar unnecessarily ([\#11598](https://github.com/matrix-org/matrix-react-sdk/pull/11598)). Contributed by @charlynguyen.
  * Use knock rooms sync to reflect the knock state ([\#11596](https://github.com/matrix-org/matrix-react-sdk/pull/11596)). Fixes vector-im/element-web#26043 and vector-im/element-web#26044. Contributed by @charlynguyen.
  * Fix avatar in right panel not using the correct font ([\#11593](https://github.com/matrix-org/matrix-react-sdk/pull/11593)). Fixes vector-im/element-web#26061. Contributed by @MidhunSureshR.
  * Add waits in Spotlight Cypress tests, hoping this unflakes them ([\#11590](https://github.com/matrix-org/matrix-react-sdk/pull/11590)). Fixes vector-im/element-web#26053, vector-im/element-web#26140 vector-im/element-web#26139 and vector-im/element-web#26138. Contributed by @andybalaam.
  * Fix vertical alignment of default avatar font ([\#11582](https://github.com/matrix-org/matrix-react-sdk/pull/11582)). Fixes vector-im/element-web#26081.
  * Fix avatars in public room & space search being flex shrunk ([\#11580](https://github.com/matrix-org/matrix-react-sdk/pull/11580)). Fixes vector-im/element-web#26133.
  * Fix EventTile avatars being rendered with a size of 0 instead of hidden ([\#11558](https://github.com/matrix-org/matrix-react-sdk/pull/11558)). Fixes vector-im/element-web#26075.
* Mon Sep 25 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.43
  [#]# 🔒 Security
  * upgrade electron to 26.2.1 to fix CVE-2023-4863 ([\#1226](https://github.com/vector-im/element-desktop/pull/1226)). Contributed by @selfisekai.
- Version 1.11.42
  [#]# 🐛 Bug Fixes
  * Update Compound to fix Firefox-specific avatar regression ([\#11604](https://github.com/matrix-org/matrix-react-sdk/pull/11604)). Fixes vector-im/element-web#26155.
- Version 1.11.41
  [#]# ✨ Features
  * Make SVGR icons use forward ref ([\#26082](https://github.com/vector-im/element-web/pull/26082)).
  * Add support for rendering a custom wrapper around Element ([\#25537](https://github.com/vector-im/element-web/pull/25537)). Contributed by @maheichyk.
  * Allow creating public knock rooms ([\#11481](https://github.com/matrix-org/matrix-react-sdk/pull/11481)). Contributed by @charlynguyen.
  * Render custom images in reactions according to MSC4027 ([\#11087](https://github.com/matrix-org/matrix-react-sdk/pull/11087)). Contributed by @sumnerevans.
  * Introduce room knocks bar ([\#11475](https://github.com/matrix-org/matrix-react-sdk/pull/11475)). Contributed by @charlynguyen.
  * Room header UI updates ([\#11507](https://github.com/matrix-org/matrix-react-sdk/pull/11507)). Fixes vector-im/element-web#25892.
  * Remove green "verified" bar for encrypted events ([\#11496](https://github.com/matrix-org/matrix-react-sdk/pull/11496)).
  * Update member count on room summary update ([\#11488](https://github.com/matrix-org/matrix-react-sdk/pull/11488)).
  * Support for E2EE in Element Call  ([\#11492](https://github.com/matrix-org/matrix-react-sdk/pull/11492)).
  * Allow requesting to join knock rooms via spotlight ([\#11482](https://github.com/matrix-org/matrix-react-sdk/pull/11482)). Contributed by @charlynguyen.
  * Lock out the first tab if Element is opened in a second tab. ([\#11425](https://github.com/matrix-org/matrix-react-sdk/pull/11425)). Fixes vector-im/element-web#25157.
  * Change avatar to use Compound implementation ([\#11448](https://github.com/matrix-org/matrix-react-sdk/pull/11448)).
  [#]# 🐛 Bug Fixes
  * Fix vertical alignment of default avatar font ([\#11582](https://github.com/matrix-org/matrix-react-sdk/pull/11582)). Fixes vector-im/element-web#26081.
  * Fix avatars in public room & space search being flex shrunk ([\#11580](https://github.com/matrix-org/matrix-react-sdk/pull/11580)). Fixes vector-im/element-web#26133.
  * Fix EventTile avatars being rendered with a size of 0 instead of hidden ([\#11558](https://github.com/matrix-org/matrix-react-sdk/pull/11558)). Fixes vector-im/element-web#26075.
  * Updated no drag zones ([\#1193](https://github.com/vector-im/element-desktop/pull/1193)).
  * Fix compound external assets path in bundle ([\#26069](https://github.com/vector-im/element-web/pull/26069)).
  * Use RoomStateEvent.Update for knocks ([\#11516](https://github.com/matrix-org/matrix-react-sdk/pull/11516)). Contributed by @charlynguyen.
  * Prevent event propagation when clicking icon buttons ([\#11515](https://github.com/matrix-org/matrix-react-sdk/pull/11515)).
  * Only display RoomKnocksBar when feature flag is enabled ([\#11513](https://github.com/matrix-org/matrix-react-sdk/pull/11513)). Contributed by @andybalaam.
  * Fix avatars of knock members for people tab of room settings ([\#11506](https://github.com/matrix-org/matrix-react-sdk/pull/11506)). Fixes vector-im/element-web#26083. Contributed by @charlynguyen.
  * Fixes read receipt avatar offset ([\#11483](https://github.com/matrix-org/matrix-react-sdk/pull/11483)). Fixes vector-im/element-web#26067, vector-im/element-web#26064 vector-im/element-web#26059 and vector-im/element-web#26061.
  * Fix avatar defects ([\#11473](https://github.com/matrix-org/matrix-react-sdk/pull/11473)). Fixes vector-im/element-web#26051 and vector-im/element-web#26046.
  * Fix consistent avatar output for Percy ([\#11472](https://github.com/matrix-org/matrix-react-sdk/pull/11472)). Fixes vector-im/element-web#26049 and vector-im/element-web#26052.
  * Fix colour of avatar and colour matching with username ([\#11470](https://github.com/matrix-org/matrix-react-sdk/pull/11470)). Fixes vector-im/element-web#26042.
  * Fix incompatibility of Soft Logout with Element-R ([\#11468](https://github.com/matrix-org/matrix-react-sdk/pull/11468)).
  * Fix instances of double translation and guard translation calls using typescript ([\#11443](https://github.com/matrix-org/matrix-react-sdk/pull/11443)).
- Version 1.11.40
  [#]# ✨ Features
  * Add FreeBSD support ([\#1163](https://github.com/vector-im/element-desktop/pull/1163)). Contributed by @lwhsu.
  * Hide account deactivation for externally managed accounts ([\#11445](https://github.com/matrix-org/matrix-react-sdk/pull/11445)). Fixes vector-im/element-web#26022. Contributed by @kerryarchibald.
  * OIDC: Redirect to delegated auth provider when signing out ([\#11432](https://github.com/matrix-org/matrix-react-sdk/pull/11432)). Fixes vector-im/element-web#26000. Contributed by @kerryarchibald.
  * Disable 3pid fields in settings when `m.3pid_changes` capability is disabled ([\#11430](https://github.com/matrix-org/matrix-react-sdk/pull/11430)). Fixes vector-im/element-web#25995. Contributed by @kerryarchibald.
  * OIDC: disable multi session signout for OIDC-aware servers in session manager ([\#11431](https://github.com/matrix-org/matrix-react-sdk/pull/11431)). Contributed by @kerryarchibald.
  * Implement updated open dialog method of the Module API ([\#11395](https://github.com/matrix-org/matrix-react-sdk/pull/11395)). Contributed by @dhenneke.
  * Polish & delabs `Exploring public spaces` feature ([\#11423](https://github.com/matrix-org/matrix-react-sdk/pull/11423)).
  * Treat lists with a single empty item as plain text, not Markdown. ([\#6833](https://github.com/matrix-org/matrix-react-sdk/pull/6833)). Fixes vector-im/element-meta#1265.
  * Allow managing room knocks ([\#11404](https://github.com/matrix-org/matrix-react-sdk/pull/11404)). Contributed by @charlynguyen.
  * Pin the action buttons to the bottom of the scrollable dialogs ([\#11407](https://github.com/matrix-org/matrix-react-sdk/pull/11407)). Contributed by @dhenneke.
  * Support Matrix 1.1 (drop legacy r0 versions) ([\#9819](https://github.com/matrix-org/matrix-react-sdk/pull/9819)).
  [#]# 🐛 Bug Fixes
  * Don't intercept Ctrl + Cmd + Q on macOS ([\#1174](https://github.com/vector-im/element-desktop/pull/1174)). Contributed by @zhaofengli.
  * Improve selectors for macos app draggable regions ([\#1170](https://github.com/vector-im/element-desktop/pull/1170)). Fixes #1169.
  * Fix path separator for Windows based systems ([\#25997](https://github.com/vector-im/element-web/pull/25997)).
  * Fix instances of double translation and guard translation calls using typescript ([\#11443](https://github.com/matrix-org/matrix-react-sdk/pull/11443)).
  * Fix export type "Current timeline" to match its behaviour to its name ([\#11426](https://github.com/matrix-org/matrix-react-sdk/pull/11426)). Fixes vector-im/element-web#25988.
  * Fix Room Settings > Notifications file upload input being shown superfluously ([\#11415](https://github.com/matrix-org/matrix-react-sdk/pull/11415)). Fixes vector-im/element-web#18392.
  * Simplify registration with email validation ([\#11398](https://github.com/matrix-org/matrix-react-sdk/pull/11398)). Fixes vector-im/element-web#25832 vector-im/element-web#23601 and vector-im/element-web#22297.
  * correct home server URL ([\#11391](https://github.com/matrix-org/matrix-react-sdk/pull/11391)). Fixes vector-im/element-web#25931. Contributed by @NSV1991.
  * Include non-matching DMs in Spotlight recent conversations when the DM's userId is part of the search API results ([\#11374](https://github.com/matrix-org/matrix-react-sdk/pull/11374)). Contributed by @mgcm.
  * Fix useRoomMembers missing updates causing incorrect membership counts ([\#11392](https://github.com/matrix-org/matrix-react-sdk/pull/11392)). Fixes vector-im/element-web#17096.
  * Show error when searching public rooms fails ([\#11378](https://github.com/matrix-org/matrix-react-sdk/pull/11378)).
- Version 1.11.39
  [#]# 🦖 Deprecations
  * Deprecate camelCase config options ([\#25800](https://github.com/vector-im/element-web/pull/25800)).
  * Deprecate customisations in favour of Module API ([\#25736](https://github.com/vector-im/element-web/pull/25736)). Fixes vector-im/element-web#25733.
  [#]# ✨ Features
  * Switch to hidden titleBar on macOS to integrate the app better ([\#1101](https://github.com/vector-im/element-desktop/pull/1101)).
  * Update labs.md for knock rooms ([\#25923](https://github.com/vector-im/element-web/pull/25923)). Contributed by @charlynguyen.
  * Package release builds of element-web in package.element.io debs ([\#25198](https://github.com/vector-im/element-web/pull/25198)).
  * Allow knocking rooms ([\#11353](https://github.com/matrix-org/matrix-react-sdk/pull/11353)). Contributed by @charlynguyen.
  * Support adding space-restricted joins on rooms not members of those spaces ([\#9017](https://github.com/matrix-org/matrix-react-sdk/pull/9017)). Fixes vector-im/element-web#19213.
  * Clear requiresClient and show pop-out if widget-api fails to ready ([\#11321](https://github.com/matrix-org/matrix-react-sdk/pull/11321)). Fixes vector-im/customer-retainer#73.
  * Bump pagination sizes due to hidden events ([\#11342](https://github.com/matrix-org/matrix-react-sdk/pull/11342)).
  * Remove display of key backup signatures from backup settings ([\#11333](https://github.com/matrix-org/matrix-react-sdk/pull/11333)).
  * Use PassphraseFields in ExportE2eKeysDialog to enforce minimum passphrase complexity ([\#11222](https://github.com/matrix-org/matrix-react-sdk/pull/11222)). Fixes vector-im/element-web#9478.
  [#]# 🐛 Bug Fixes
  * Prevent the media lightbox sender info clipping with traffic light on macos ([\#1141](https://github.com/vector-im/element-desktop/pull/1141)). Fixes #1140.
  * Restore macOs room header dragability ([\#1136](https://github.com/vector-im/element-desktop/pull/1136)). Fixes #1135.
  * Fix ability to interact with room topic in header ([\#1126](https://github.com/vector-im/element-desktop/pull/1126)). Fixes undefined/element-desktop#1125.
  * Fix "Export chat" not respecting configured time format in plain text mode ([\#10696](https://github.com/matrix-org/matrix-react-sdk/pull/10696)). Fixes vector-im/element-web#23838. Contributed by @rashmitpankhania.
  * Fix some missing 1-count pluralisations around event list summaries ([\#11371](https://github.com/matrix-org/matrix-react-sdk/pull/11371)). Fixes vector-im/element-web#25925.
  * Fix create subspace dialog not working for public space creation ([\#11367](https://github.com/matrix-org/matrix-react-sdk/pull/11367)). Fixes vector-im/element-web#25916.
  * Search for users on paste ([\#11304](https://github.com/matrix-org/matrix-react-sdk/pull/11304)). Fixes vector-im/element-web#17523. Contributed by @peterscheu-aceart.
  * Fix AppTile context menu not always showing up when it has options ([\#11358](https://github.com/matrix-org/matrix-react-sdk/pull/11358)). Fixes vector-im/element-web#25914.
  * Fix clicking on home all rooms space notification not working ([\#11337](https://github.com/matrix-org/matrix-react-sdk/pull/11337)). Fixes vector-im/element-web#22844.
  * Fix joining a suggested room switching space away ([\#11347](https://github.com/matrix-org/matrix-react-sdk/pull/11347)). Fixes vector-im/element-web#25838.
  * Fix home/all rooms context menu in space panel ([\#11350](https://github.com/matrix-org/matrix-react-sdk/pull/11350)). Fixes vector-im/element-web#25896.
  * Make keyboard handling in and out of autocomplete completions consistent ([\#11344](https://github.com/matrix-org/matrix-react-sdk/pull/11344)). Fixes vector-im/element-web#25878.
  * De-duplicate reactions by sender to account for faulty/malicious servers ([\#11340](https://github.com/matrix-org/matrix-react-sdk/pull/11340)). Fixes vector-im/element-web#25872.
  * Fix disable_3pid_login being ignored for the email field ([\#11335](https://github.com/matrix-org/matrix-react-sdk/pull/11335)). Fixes vector-im/element-web#25863.
  * Upgrade wysiwyg editor for ctrl+backspace windows fix ([\#11324](https://github.com/matrix-org/matrix-react-sdk/pull/11324)). Fixes vector-im/verticals-internal#102.
  * Unhide the view source event toggle - it works well enough ([\#11336](https://github.com/matrix-org/matrix-react-sdk/pull/11336)). Fixes vector-im/element-web#25861.
* Fri Aug  4 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.38
  [#]# ✨ Features
  * Package release builds of element-web in package.element.io debs ([\#25921](https://github.com/vector-im/element-web/pull/25921)). Contributed by @RiotRobot.
  [#]# 🐛 Bug Fixes
  * Revert to using the /presence API for presence ([\#11366](https://github.com/matrix-org/matrix-react-sdk/pull/11366))
* Tue Jul 18 2023 Dominik Heidler <dheidler@suse.com>
- Version 1.11.36
  [#]# 🔒 Security
  * Fixes for [CVE-2023-37259](https://cve.mitre.org/cgi-bin/cvekey.cgi?keyword=CVE-2023-37259) / [GHSA-c9vx-2g7w-rp65](https://github.com/matrix-org/matrix-react-sdk/security/advisories/GHSA-c9vx-2g7w-rp65)
  [#]# 🦖 Deprecations
  * Deprecate customisations in favour of Module API ([\#25736](https://github.com/vector-im/element-web/pull/25736)). Fixes vector-im/element-web#25733.
  [#]# ✨ Features
  * OIDC: store initial screen in session storage  ([\#25688](https://github.com/vector-im/element-web/pull/25688)). Fixes vector-im/element-web#25656. Contributed by @kerryarchibald.
  * Allow default_server_config as a fallback config ([\#25682](https://github.com/vector-im/element-web/pull/25682)). Contributed by @ShadowRZ.
  * OIDC: remove auth params from url after login attempt ([\#25664](https://github.com/vector-im/element-web/pull/25664)). Contributed by @kerryarchibald.
  * feat(faq): remove keyboard shortcuts button ([\#9342](https://github.com/matrix-org/matrix-react-sdk/pull/9342)). Fixes vector-im/element-web#22625. Contributed by @gefgu.
  * GYU: Update banner ([\#11211](https://github.com/matrix-org/matrix-react-sdk/pull/11211)). Fixes vector-im/element-web#25530. Contributed by @justjanne.
  * Linkify mxc:// URLs as links to your media repo ([\#11213](https://github.com/matrix-org/matrix-react-sdk/pull/11213)). Fixes vector-im/element-web#6942.
  * OIDC: Log in ([\#11199](https://github.com/matrix-org/matrix-react-sdk/pull/11199)). Fixes vector-im/element-web#25657. Contributed by @kerryarchibald.
  * Handle all permitted url schemes in linkify ([\#11215](https://github.com/matrix-org/matrix-react-sdk/pull/11215)). Fixes vector-im/element-web#4457 and vector-im/element-web#8720.
  * Autoapprove Element Call oidc requests ([\#11209](https://github.com/matrix-org/matrix-react-sdk/pull/11209)). Contributed by @toger5.
  * Allow creating knock rooms ([\#11182](https://github.com/matrix-org/matrix-react-sdk/pull/11182)). Contributed by @charlynguyen.
  * Expose and pre-populate thread ID in devtools dialog ([\#10953](https://github.com/matrix-org/matrix-react-sdk/pull/10953)).
  * Hide URL preview if it will be empty ([\#9029](https://github.com/matrix-org/matrix-react-sdk/pull/9029)).
  * Change wording from avatar to profile picture ([\#7015](https://github.com/matrix-org/matrix-react-sdk/pull/7015)). Fixes vector-im/element-meta#1331. Contributed by @aaronraimist.
  * Quick and dirty devtool to explore state history ([\#11197](https://github.com/matrix-org/matrix-react-sdk/pull/11197)).
  * Consider more user inputs when calculating zxcvbn score ([\#11180](https://github.com/matrix-org/matrix-react-sdk/pull/11180)).
  * GYU: Account Notification Settings ([\#11008](https://github.com/matrix-org/matrix-react-sdk/pull/11008)). Fixes vector-im/element-web#24567. Contributed by @justjanne.
  * Compound Typography pass ([\#11103](https://github.com/matrix-org/matrix-react-sdk/pull/11103)). Fixes vector-im/element-web#25548.
  * OIDC: navigate to authorization endpoint ([\#11096](https://github.com/matrix-org/matrix-react-sdk/pull/11096)). Fixes vector-im/element-web#25574. Contributed by @kerryarchibald.
  [#]# 🐛 Bug Fixes
  * Fix read receipt sending behaviour around thread roots ([\#3600](https://github.com/matrix-org/matrix-js-sdk/pull/3600)).
  * Fix missing metaspace notification badges ([\#11269](https://github.com/matrix-org/matrix-react-sdk/pull/11269)). Fixes vector-im/element-web#25679.
  * Make checkboxes less rounded ([\#11224](https://github.com/matrix-org/matrix-react-sdk/pull/11224)). Contributed by @andybalaam.
  * GYU: Fix issues with audible keywords without activated mentions ([\#11218](https://github.com/matrix-org/matrix-react-sdk/pull/11218)). Contributed by @justjanne.
  * PosthogAnalytics unwatch settings on logout ([\#11207](https://github.com/matrix-org/matrix-react-sdk/pull/11207)). Fixes vector-im/element-web#25703.
  * Avoid trying to set room account data for pinned events as guest ([\#11216](https://github.com/matrix-org/matrix-react-sdk/pull/11216)). Fixes vector-im/element-web#6300.
  * GYU: Disable sound for DMs checkbox when DM notifications are disabled ([\#11210](https://github.com/matrix-org/matrix-react-sdk/pull/11210)). Contributed by @justjanne.
  * force to allow calls without video and audio in embedded mode ([\#11131](https://github.com/matrix-org/matrix-react-sdk/pull/11131)). Contributed by @EnricoSchw.
  * Fix room tile text clipping ([\#11196](https://github.com/matrix-org/matrix-react-sdk/pull/11196)). Fixes vector-im/element-web#25718.
  * Handle newlines in user pills ([\#11166](https://github.com/matrix-org/matrix-react-sdk/pull/11166)). Fixes vector-im/element-web#10994.
  * Limit width of user menu in space panel ([\#11192](https://github.com/matrix-org/matrix-react-sdk/pull/11192)). Fixes vector-im/element-web#22627.
  * Add isLocation to ComposerEvent analytics events ([\#11187](https://github.com/matrix-org/matrix-react-sdk/pull/11187)). Contributed by @andybalaam.
  * Fix: hide unsupported login elements ([\#11185](https://github.com/matrix-org/matrix-react-sdk/pull/11185)). Fixes vector-im/element-web#25711. Contributed by @kerryarchibald.
  * Scope smaller font size to user info panel ([\#11178](https://github.com/matrix-org/matrix-react-sdk/pull/11178)). Fixes vector-im/element-web#25683.
  * Apply i18n to strings in the html export ([\#11176](https://github.com/matrix-org/matrix-react-sdk/pull/11176)).
  * Inhibit url previews on MXIDs containing slashes same as those without ([\#11160](https://github.com/matrix-org/matrix-react-sdk/pull/11160)).
  * Make event info size consistent with state events ([\#11181](https://github.com/matrix-org/matrix-react-sdk/pull/11181)).
  * Fix markdown content spacing ([\#11177](https://github.com/matrix-org/matrix-react-sdk/pull/11177)). Fixes vector-im/element-web#25685.
  * Fix font-family definition for emojis ([\#11170](https://github.com/matrix-org/matrix-react-sdk/pull/11170)). Fixes vector-im/element-web#25686.
  * Fix spurious error sending receipt in thread errors ([\#11157](https://github.com/matrix-org/matrix-react-sdk/pull/11157)).
  * Consider the empty push rule actions array equiv to deprecated dont_notify ([\#11155](https://github.com/matrix-org/matrix-react-sdk/pull/11155)). Fixes vector-im/element-web#25674.
  * Only trap escape key for cancel reply if there is a reply ([\#11140](https://github.com/matrix-org/matrix-react-sdk/pull/11140)). Fixes vector-im/element-web#25640.
  * Update linkify to 4.1.1 ([\#11132](https://github.com/matrix-org/matrix-react-sdk/pull/11132)). Fixes vector-im/element-web#23806.
* Fri Jun 23 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.34
  [#]# ✨ Features
  * OIDC: add delegatedauthentication to validated server config ([\#11053](https://github.com/matrix-org/matrix-react-sdk/pull/11053)). Contributed by @kerryarchibald.
  * Allow image pasting in plain mode in RTE ([\#11056](https://github.com/matrix-org/matrix-react-sdk/pull/11056)). Contributed by @alunturner.
  * Show room options menu if "UIComponent.roomOptionsMenu" is enabled ([\#10365](https://github.com/matrix-org/matrix-react-sdk/pull/10365)). Contributed by @maheichyk.
  * Allow image pasting in rich text mode in RTE ([\#11049](https://github.com/matrix-org/matrix-react-sdk/pull/11049)). Contributed by @alunturner.
  * Update voice broadcast redaction to use MSC3912 `with_rel_type` instead of `with_relations` ([\#11014](https://github.com/matrix-org/matrix-react-sdk/pull/11014)). Fixes vector-im/element-web#25471.
  * Add config to skip widget_build_url for DM rooms ([\#11044](https://github.com/matrix-org/matrix-react-sdk/pull/11044)). Fixes vector-im/customer-retainer#74.
  * Inhibit interactions on forward dialog message previews ([\#11025](https://github.com/matrix-org/matrix-react-sdk/pull/11025)). Fixes vector-im/element-web#23459.
  * Removed `DecryptionFailureBar.tsx` ([\#11027](https://github.com/matrix-org/matrix-react-sdk/pull/11027)). Fixes vector-im/element-meta#1358. Contributed by @florianduros.
  [#]# 🐛 Bug Fixes
  * Fix translucent `TextualEvent` on search results panel ([\#10810](https://github.com/matrix-org/matrix-react-sdk/pull/10810)). Fixes vector-im/element-web#25292. Contributed by @luixxiul.
  * Matrix matrix scheme permalink constructor not stripping query params ([\#11060](https://github.com/matrix-org/matrix-react-sdk/pull/11060)). Fixes vector-im/element-web#25535.
  * Fix: "manually verify by text" does nothing ([\#11059](https://github.com/matrix-org/matrix-react-sdk/pull/11059)). Fixes vector-im/element-web#25375. Contributed by @kerryarchibald.
  * Make group calls respect the ICE fallback setting ([\#11047](https://github.com/matrix-org/matrix-react-sdk/pull/11047)). Fixes vector-im/voip-internal#65.
  * Align list items on the tooltip to the start ([\#11041](https://github.com/matrix-org/matrix-react-sdk/pull/11041)). Fixes vector-im/element-web#25355. Contributed by @luixxiul.
  * Clear thread panel event permalink when changing rooms ([\#11024](https://github.com/matrix-org/matrix-react-sdk/pull/11024)). Fixes vector-im/element-web#25484.
  * Fix spinner placement on pinned widgets being reloaded ([\#10970](https://github.com/matrix-org/matrix-react-sdk/pull/10970)). Fixes vector-im/element-web#25431. Contributed by @luixxiul.
* Fri Jun 23 2023 Dominik Heidler <dheidler@suse.de>
- Be multi-arch friendly - Add aarch64 support
* Thu Jun 15 2023 Dominik Heidler <dheidler@suse.de>
- Build with native extensons
  - keytar for talking to system keyring
  - seshat for maintaining encrypted sqlite db for msg search
* Wed Jun  7 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.32
  [#]# ✨ Features
  * Redirect to the SSO page if `sso_redirect_options.on_welcome_page` is enabled and the URL hash is empty ([\#25495](https://github.com/vector-im/element-web/pull/25495)). Contributed by @dhenneke.
  * vector/index.html: Allow fetching blob urls ([\#25336](https://github.com/vector-im/element-web/pull/25336)). Contributed by @SuperKenVery.
  * When joining room in sub-space join the parents too ([\#11011](https://github.com/matrix-org/matrix-react-sdk/pull/11011)).
  * Include thread replies in message previews ([\#10631](https://github.com/matrix-org/matrix-react-sdk/pull/10631)). Fixes vector-im/element-web#23920.
  * Use semantic headings in space preferences ([\#11021](https://github.com/matrix-org/matrix-react-sdk/pull/11021)). Contributed by @kerryarchibald.
  * Use semantic headings in user settings - Ignored users ([\#11006](https://github.com/matrix-org/matrix-react-sdk/pull/11006)). Contributed by @kerryarchibald.
  * Use semantic headings in user settings - profile ([\#10973](https://github.com/matrix-org/matrix-react-sdk/pull/10973)). Fixes vector-im/element-web#25461. Contributed by @kerryarchibald.
  * Use semantic headings in user settings - account ([\#10972](https://github.com/matrix-org/matrix-react-sdk/pull/10972)). Contributed by @kerryarchibald.
  * Support `Insert from iPhone or iPad` in Safari ([\#10851](https://github.com/matrix-org/matrix-react-sdk/pull/10851)). Fixes vector-im/element-web#25327. Contributed by @SuperKenVery.
  * Specify supportedStages for User Interactive Auth ([\#10975](https://github.com/matrix-org/matrix-react-sdk/pull/10975)). Fixes vector-im/element-web#19605.
  * Pass device id to widgets ([\#10209](https://github.com/matrix-org/matrix-react-sdk/pull/10209)). Contributed by @Fox32.
  * Use semantic headings in user settings - discovery ([\#10838](https://github.com/matrix-org/matrix-react-sdk/pull/10838)). Contributed by @kerryarchibald.
  * Use semantic headings in user settings -  Notifications ([\#10948](https://github.com/matrix-org/matrix-react-sdk/pull/10948)). Contributed by @kerryarchibald.
  * Use semantic headings in user settings - spellcheck and language ([\#10959](https://github.com/matrix-org/matrix-react-sdk/pull/10959)). Contributed by @kerryarchibald.
  * Use semantic headings in user settings Appearance ([\#10827](https://github.com/matrix-org/matrix-react-sdk/pull/10827)). Contributed by @kerryarchibald.
  * Use semantic heading in user settings Sidebar & Voip ([\#10782](https://github.com/matrix-org/matrix-react-sdk/pull/10782)). Contributed by @kerryarchibald.
  * Use semantic headings in user settings Security ([\#10774](https://github.com/matrix-org/matrix-react-sdk/pull/10774)). Contributed by @kerryarchibald.
  * Use semantic headings in user settings - integrations and account deletion ([\#10837](https://github.com/matrix-org/matrix-react-sdk/pull/10837)). Fixes vector-im/element-web#25378. Contributed by @kerryarchibald.
  * Use semantic headings in user settings Preferences ([\#10794](https://github.com/matrix-org/matrix-react-sdk/pull/10794)). Contributed by @kerryarchibald.
  * Use semantic headings in user settings Keyboard ([\#10793](https://github.com/matrix-org/matrix-react-sdk/pull/10793)). Contributed by @kerryarchibald.
  * RTE plain text mentions as pills ([\#10852](https://github.com/matrix-org/matrix-react-sdk/pull/10852)). Contributed by @alunturner.
  * Allow welcome.html logo to be replaced by config ([\#25339](https://github.com/vector-im/element-web/pull/25339)). Fixes vector-im/element-web#8636.
  * Use semantic headings in user settings Labs ([\#10773](https://github.com/matrix-org/matrix-react-sdk/pull/10773)). Contributed by @kerryarchibald.
  * Use semantic list elements for menu lists and tab lists ([\#10902](https://github.com/matrix-org/matrix-react-sdk/pull/10902)). Fixes vector-im/element-web#24928.
  * Fix aria-required-children axe violation ([\#10900](https://github.com/matrix-org/matrix-react-sdk/pull/10900)). Fixes vector-im/element-web#25342.
  * Enable pagination for overlay timelines ([\#10757](https://github.com/matrix-org/matrix-react-sdk/pull/10757)). Fixes vector-im/voip-internal#107.
  * Add tooltip to disabled invite button due to lack of permissions ([\#10869](https://github.com/matrix-org/matrix-react-sdk/pull/10869)). Fixes vector-im/element-web#9824.
  * Respect configured auth_header_logo_url for default Welcome page ([\#10870](https://github.com/matrix-org/matrix-react-sdk/pull/10870)).
  * Specify lazy loading for avatars ([\#10866](https://github.com/matrix-org/matrix-react-sdk/pull/10866)). Fixes vector-im/element-web#1983.
  * Room and user mentions for plain text editor ([\#10665](https://github.com/matrix-org/matrix-react-sdk/pull/10665)). Contributed by @alunturner.
  * Add audible notifcation on broadcast error ([\#10654](https://github.com/matrix-org/matrix-react-sdk/pull/10654)). Fixes vector-im/element-web#25132.
  * Fall back from server generated thumbnail to original image ([\#10853](https://github.com/matrix-org/matrix-react-sdk/pull/10853)).
  * Use semantically correct elements for room sublist context menu ([\#10831](https://github.com/matrix-org/matrix-react-sdk/pull/10831)). Fixes vector-im/customer-retainer#46.
  * Avoid calling prepareToEncrypt onKeyDown ([\#10828](https://github.com/matrix-org/matrix-react-sdk/pull/10828)).
  * Allows search to recognize full room links ([\#8275](https://github.com/matrix-org/matrix-react-sdk/pull/8275)). Contributed by @bolu-tife.
  * "Show rooms with unread messages first" should not be on by default for new users ([\#10820](https://github.com/matrix-org/matrix-react-sdk/pull/10820)). Fixes vector-im/element-web#25304. Contributed by @kerryarchibald.
  * Fix emitter handler leak in ThreadView ([\#10803](https://github.com/matrix-org/matrix-react-sdk/pull/10803)).
  * Add better error for email invites without identity server ([\#10739](https://github.com/matrix-org/matrix-react-sdk/pull/10739)). Fixes vector-im/element-web#16893.
  * Move reaction message previews out of labs ([\#10601](https://github.com/matrix-org/matrix-react-sdk/pull/10601)). Fixes vector-im/element-web#25083.
  * Sort muted rooms to the bottom of their section of the room list ([\#10592](https://github.com/matrix-org/matrix-react-sdk/pull/10592)). Fixes vector-im/element-web#25131. Contributed by @kerryarchibald.
  * Use semantic headings in user settings Help & About ([\#10752](https://github.com/matrix-org/matrix-react-sdk/pull/10752)). Contributed by @kerryarchibald.
  * use ExternalLink components for external links ([\#10758](https://github.com/matrix-org/matrix-react-sdk/pull/10758)). Contributed by @kerryarchibald.
  * Use semantic headings in space settings ([\#10751](https://github.com/matrix-org/matrix-react-sdk/pull/10751)). Contributed by @kerryarchibald.
  * Use semantic headings for room settings content ([\#10734](https://github.com/matrix-org/matrix-react-sdk/pull/10734)). Contributed by @kerryarchibald.
  [#]# 🐛 Bug Fixes
  * Use consistent fonts for Japanese text ([\#10980](https://github.com/matrix-org/matrix-react-sdk/pull/10980)). Fixes vector-im/element-web#22333 and vector-im/element-web#23899.
  * Fix: server picker validates unselected option ([\#11020](https://github.com/matrix-org/matrix-react-sdk/pull/11020)). Fixes vector-im/element-web#25488. Contributed by @kerryarchibald.
  * Fix room list notification badges going missing in compact layout ([\#11022](https://github.com/matrix-org/matrix-react-sdk/pull/11022)). Fixes vector-im/element-web#25372.
  * Fix call to `startSingleSignOn` passing enum in place of idpId ([\#10998](https://github.com/matrix-org/matrix-react-sdk/pull/10998)). Fixes vector-im/element-web#24953.
  * Remove hover effect from user name on a DM creation UI ([\#10887](https://github.com/matrix-org/matrix-react-sdk/pull/10887)). Fixes vector-im/element-web#25305. Contributed by @luixxiul.
  * Fix layout regression in public space invite dialog ([\#11009](https://github.com/matrix-org/matrix-react-sdk/pull/11009)). Fixes vector-im/element-web#25458.
  * Fix layout regression in session dropdown ([\#10999](https://github.com/matrix-org/matrix-react-sdk/pull/10999)). Fixes vector-im/element-web#25448.
  * Fix spacing regression in user settings - roles & permissions ([\#10993](https://github.com/matrix-org/matrix-react-sdk/pull/10993)). Fixes vector-im/element-web#25447 and vector-im/element-web#25451. Contributed by @kerryarchibald.
  * Fall back to receipt timestamp if we have no event (react-sdk part) ([\#10974](https://github.com/matrix-org/matrix-react-sdk/pull/10974)). Fixes vector-im/element-web#10954. Contributed by @andybalaam.
  * Fix: Room header 'view your device list' does not link to new session manager ([\#10979](https://github.com/matrix-org/matrix-react-sdk/pull/10979)). Fixes vector-im/element-web#25440. Contributed by @kerryarchibald.
  * Fix display of devices without encryption support in Settings dialog ([\#10977](https://github.com/matrix-org/matrix-react-sdk/pull/10977)). Fixes vector-im/element-web#25413.
  * Use aria descriptions instead of labels for TextWithTooltip ([\#10952](https://github.com/matrix-org/matrix-react-sdk/pull/10952)). Fixes vector-im/element-web#25398.
  * Use grapheme-splitter instead of lodash for saving emoji from being ripped apart ([\#10976](https://github.com/matrix-org/matrix-react-sdk/pull/10976)). Fixes vector-im/element-web#22196.
  * Fix: content overflow in settings subsection ([\#10960](https://github.com/matrix-org/matrix-react-sdk/pull/10960)). Fixes vector-im/element-web#25416. Contributed by @kerryarchibald.
  * Make `Privacy Notice` external link on integration manager ToS clickable ([\#10914](https://github.com/matrix-org/matrix-react-sdk/pull/10914)). Fixes vector-im/element-web#25384. Contributed by @luixxiul.
  * Ensure that open message context menus are updated when the event is sent ([\#10950](https://github.com/matrix-org/matrix-react-sdk/pull/10950)).
  * Ensure that open sticker picker dialogs are updated when the widget configuration is updated. ([\#10945](https://github.com/matrix-org/matrix-react-sdk/pull/10945)).
  * Fix big emoji in replies ([\#10932](https://github.com/matrix-org/matrix-react-sdk/pull/10932)). Fixes vector-im/element-web#24798.
  * Hide empty `MessageActionBar` on message edit history dialog ([\#10447](https://github.com/matrix-org/matrix-react-sdk/pull/10447)). Fixes vector-im/element-web#24903. Contributed by @luixxiul.
  * Fix roving tab index getting confused after dragging space order ([\#10901](https://github.com/matrix-org/matrix-react-sdk/pull/10901)).
  * Attempt a potential workaround for stuck notifs ([\#3384](https://github.com/matrix-org/matrix-js-sdk/pull/3384)). Fixes vector-im/element-web#25406. Contributed by @andybalaam.
  * Update to seshat 3.0.1 ([\#960](https://github.com/vector-im/element-desktop/pull/960)). Fixes #959.
  * Fix macos update check exploding ([\#944](https://github.com/vector-im/element-desktop/pull/944)). Fixes #668.
  * Handle trailing dot FQDNs for domain-specific config.json files ([\#25351](https://github.com/vector-im/element-web/pull/25351)). Fixes vector-im/element-web#8858.
  * Ignore edits in message previews when they concern messages other than latest ([\#10868](https://github.com/matrix-org/matrix-react-sdk/pull/10868)). Fixes vector-im/element-web#14872.
  * Send correct receipts when viewing a room ([\#10864](https://github.com/matrix-org/matrix-react-sdk/pull/10864)). Fixes vector-im/element-web#25196.
  * Fix timeline search bar being overlapped by the right panel ([\#10809](https://github.com/matrix-org/matrix-react-sdk/pull/10809)). Fixes vector-im/element-web#25291. Contributed by @luixxiul.
  * Fix the state shown for call in rooms ([\#10833](https://github.com/matrix-org/matrix-react-sdk/pull/10833)).
  * Add string for membership event where both displayname & avatar change ([\#10880](https://github.com/matrix-org/matrix-react-sdk/pull/10880)). Fixes vector-im/element-web#18026.
  * Fix people space notification badge not updating for new DM invites ([\#10849](https://github.com/matrix-org/matrix-react-sdk/pull/10849)). Fixes vector-im/element-web#23248.
  * Fix regression in emoji picker order mangling after clearing filter ([\#10854](https://github.com/matrix-org/matrix-react-sdk/pull/10854)). Fixes vector-im/element-web#25323.
  * Fix: Edit history modal crash ([\#10834](https://github.com/matrix-org/matrix-react-sdk/pull/10834)). Fixes vector-im/element-web#25309. Contributed by @kerryarchibald.
  * Fix long room address and name not being clipped on room info card and update `_RoomSummaryCard.pcss` ([\#10811](https://github.com/matrix-org/matrix-react-sdk/pull/10811)). Fixes vector-im/element-web#25293. Contributed by @luixxiul.
  * Treat thumbnail upload failures as complete upload failures ([\#10829](https://github.com/matrix-org/matrix-react-sdk/pull/10829)). Fixes vector-im/element-web#7069.
  * Update finite automata to match user identifiers as per spec ([\#10798](https://github.com/matrix-org/matrix-react-sdk/pull/10798)). Fixes vector-im/element-web#25246.
  * Fix icon on empty notification panel ([\#10817](https://github.com/matrix-org/matrix-react-sdk/pull/10817)). Fixes vector-im/element-web#25298 and vector-im/element-web#25302. Contributed by @luixxiul.
  * Fix: Threads button is highlighted when I create a new room ([\#10819](https://github.com/matrix-org/matrix-react-sdk/pull/10819)). Fixes vector-im/element-web#25284. Contributed by @kerryarchibald.
  * Fix the top heading of notification panel ([\#10818](https://github.com/matrix-org/matrix-react-sdk/pull/10818)). Fixes vector-im/element-web#25303. Contributed by @luixxiul.
  * Fix the color of the verified E2EE icon on `RoomSummaryCard` ([\#10812](https://github.com/matrix-org/matrix-react-sdk/pull/10812)). Fixes vector-im/element-web#25295. Contributed by @luixxiul.
  * Fix: No feedback when waiting for the server on a /delete_devices request with SSO ([\#10795](https://github.com/matrix-org/matrix-react-sdk/pull/10795)). Fixes vector-im/element-web#23096. Contributed by @kerryarchibald.
  * Fix: reveal images when image previews are disabled ([\#10781](https://github.com/matrix-org/matrix-react-sdk/pull/10781)). Fixes vector-im/element-web#25271. Contributed by @kerryarchibald.
  * Fix accessibility issues around the room list and space panel ([\#10717](https://github.com/matrix-org/matrix-react-sdk/pull/10717)). Fixes vector-im/element-web#13345.
  * Ensure tooltip contents is linked via aria to the target element ([\#10729](https://github.com/matrix-org/matrix-react-sdk/pull/10729)). Fixes vector-im/customer-retainer#43.
* Tue Apr 25 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.30
  [#]# 🔒 Security
  * Fixes for [CVE-2023-30609](https://cve.mitre.org/cgi-bin/cvekey.cgi?keyword=CVE-2023-30609) / GHSA-xv83-x443-7rmw
  [#]# ✨ Features
  * Pick sensible default option for phone country dropdown ([\#10627](https://github.com/matrix-org/matrix-react-sdk/pull/10627)). Fixes vector-im/element-web#3528.
  * Relate field validation tooltip via aria-describedby ([\#10522](https://github.com/matrix-org/matrix-react-sdk/pull/10522)). Fixes vector-im/element-web#24963.
  * Handle more completion types in rte autocomplete ([\#10560](https://github.com/matrix-org/matrix-react-sdk/pull/10560)). Contributed by @alunturner.
  * Show a tile for an unloaded predecessor room if it has via_servers ([\#10483](https://github.com/matrix-org/matrix-react-sdk/pull/10483)). Contributed by @andybalaam.
  * Exclude message timestamps from aria live region ([\#10584](https://github.com/matrix-org/matrix-react-sdk/pull/10584)). Fixes vector-im/element-web#5696.
  * Make composer format bar an aria toolbar ([\#10583](https://github.com/matrix-org/matrix-react-sdk/pull/10583)). Fixes vector-im/element-web#11283.
  * Improve accessibility of font slider ([\#10473](https://github.com/matrix-org/matrix-react-sdk/pull/10473)). Fixes vector-im/element-web#20168 and vector-im/element-web#24962.
  * fix file size display from kB to KB ([\#10561](https://github.com/matrix-org/matrix-react-sdk/pull/10561)). Fixes vector-im/element-web#24866. Contributed by @NSV1991.
  * Handle /me in rte ([\#10558](https://github.com/matrix-org/matrix-react-sdk/pull/10558)). Contributed by @alunturner.
  * bind html with switch for manage extension setting option ([\#10553](https://github.com/matrix-org/matrix-react-sdk/pull/10553)). Contributed by @NSV1991.
  * Handle command completions in RTE ([\#10521](https://github.com/matrix-org/matrix-react-sdk/pull/10521)). Contributed by @alunturner.
  * Add room and user avatars to rte ([\#10497](https://github.com/matrix-org/matrix-react-sdk/pull/10497)). Contributed by @alunturner.
  * Support for MSC3882 revision 1 ([\#10443](https://github.com/matrix-org/matrix-react-sdk/pull/10443)). Contributed by @hughns.
  * Check profiles before starting a DM ([\#10472](https://github.com/matrix-org/matrix-react-sdk/pull/10472)). Fixes vector-im/element-web#24830.
  * Quick settings: Change the copy / labels on the options ([\#10427](https://github.com/matrix-org/matrix-react-sdk/pull/10427)). Fixes vector-im/element-web#24522. Contributed by @justjanne.
  * Update rte autocomplete styling ([\#10503](https://github.com/matrix-org/matrix-react-sdk/pull/10503)). Contributed by @alunturner.
  [#]# 🐛 Bug Fixes
  * Workaround Squirrel.Mac wedging app restart after failed update check ([\#629](https://github.com/vector-im/element-desktop/pull/629)).
  * Fix error about webContents on log out ([\#627](https://github.com/vector-im/element-desktop/pull/627)).
  * Fix error when breadcrumb image fails to load ([\#609](https://github.com/vector-im/element-desktop/pull/609)).
  * Fix create subspace dialog not working ([\#10652](https://github.com/matrix-org/matrix-react-sdk/pull/10652)). Fixes vector-im/element-web#24882
  * Fix multiple accessibility defects identified by AXE ([\#10606](https://github.com/matrix-org/matrix-react-sdk/pull/10606)).
  * Fix view source from edit history dialog always showing latest event ([\#10626](https://github.com/matrix-org/matrix-react-sdk/pull/10626)). Fixes vector-im/element-web#21859.
  * #21451 Fix WebGL disabled error message ([\#10589](https://github.com/matrix-org/matrix-react-sdk/pull/10589)). Contributed by @rashmitpankhania.
  * Properly translate errors in `AddThreepid.ts` so they show up translated to the user but not in our logs ([\#10432](https://github.com/matrix-org/matrix-react-sdk/pull/10432)). Contributed by @MadLittleMods.
  * Fix overflow on auth pages ([\#10605](https://github.com/matrix-org/matrix-react-sdk/pull/10605)). Fixes vector-im/element-web#19548.
  * Fix incorrect avatar background colour when using a custom theme ([\#10598](https://github.com/matrix-org/matrix-react-sdk/pull/10598)). Contributed by @jdauphant.
  * Remove dependency on `org.matrix.e2e_cross_signing` unstable feature ([\#10593](https://github.com/matrix-org/matrix-react-sdk/pull/10593)).
  * Update setting description to match reality ([\#10600](https://github.com/matrix-org/matrix-react-sdk/pull/10600)). Fixes vector-im/element-web#25106.
  * Fix no identity server in help & about settings ([\#10563](https://github.com/matrix-org/matrix-react-sdk/pull/10563)). Fixes vector-im/element-web#25077.
  * Fix: Images no longer reserve their space in the timeline correctly ([\#10571](https://github.com/matrix-org/matrix-react-sdk/pull/10571)). Fixes vector-im/element-web#25082. Contributed by @kerryarchibald.
  * Fix issues with inhibited accessible focus outlines ([\#10579](https://github.com/matrix-org/matrix-react-sdk/pull/10579)). Fixes vector-im/element-web#19742.
  * Fix read receipts falling from sky ([\#10576](https://github.com/matrix-org/matrix-react-sdk/pull/10576)). Fixes vector-im/element-web#25081.
  * Fix avatar text issue in rte ([\#10559](https://github.com/matrix-org/matrix-react-sdk/pull/10559)). Contributed by @alunturner.
  * fix resizer only work with left mouse click ([\#10546](https://github.com/matrix-org/matrix-react-sdk/pull/10546)). Contributed by @NSV1991.
  * Fix send two join requests when joining a room from spotlight search ([\#10534](https://github.com/matrix-org/matrix-react-sdk/pull/10534)). Fixes vector-im/element-web#25054.
  * Highlight event when any version triggered a highlight ([\#10502](https://github.com/matrix-org/matrix-react-sdk/pull/10502)). Fixes vector-im/element-web#24923 and vector-im/element-web#24970. Contributed by @kerryarchibald.
  * Fix spacing of headings of integration manager on General settings tab ([\#10232](https://github.com/matrix-org/matrix-react-sdk/pull/10232)). Fixes vector-im/element-web#24085. Contributed by @luixxiul.
* Fri Apr 14 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.29
  [#]# ✨ Features
  * Ship linux tarball with static sqlcipher ([\#597](https://github.com/vector-im/element-desktop/pull/597)). Fixes vector-im/element-web#18486.
  * Show recent room breadcrumbs on touchbar ([\#183](https://github.com/vector-im/element-desktop/pull/183)). Fixes vector-im/element-web#15998.
  * Clear electron data when logging out ([\#578](https://github.com/vector-im/element-desktop/pull/578)).
  * Send Electron crashpad reports to Sentry from Nightly ([\#579](https://github.com/vector-im/element-desktop/pull/579)). Fixes vector-im/element-web#18263.
  * Recommend element-io-archive-keyring from our Debian package ([\#566](https://github.com/vector-im/element-desktop/pull/566)).
  * Allow desktop app to expose recent rooms in UI integrations ([\#16940](https://github.com/vector-im/element-web/pull/16940)).
  * Add API params to mute audio and/or video in Jitsi calls by default ([\#24820](https://github.com/vector-im/element-web/pull/24820)). Contributed by @dhenneke.
  * Style mentions as pills in rich text editor ([\#10448](https://github.com/matrix-org/matrix-react-sdk/pull/10448)). Contributed by @alunturner.
  * Show room create icon if "UIComponent.roomCreation" is enabled ([\#10364](https://github.com/matrix-org/matrix-react-sdk/pull/10364)). Contributed by @maheichyk.
  * Mentions as links rte ([\#10463](https://github.com/matrix-org/matrix-react-sdk/pull/10463)). Contributed by @alunturner.
  * Better error handling in jump to date ([\#10405](https://github.com/matrix-org/matrix-react-sdk/pull/10405)). Contributed by @MadLittleMods.
  * Show "Invite" menu option if "UIComponent.sendInvites" is enabled. ([\#10363](https://github.com/matrix-org/matrix-react-sdk/pull/10363)). Contributed by @maheichyk.
  * Added `UserProfilesStore`, `LruCache` and user permalink profile caching ([\#10425](https://github.com/matrix-org/matrix-react-sdk/pull/10425)). Fixes vector-im/element-web#10559.
  * Mentions as links rte ([\#10422](https://github.com/matrix-org/matrix-react-sdk/pull/10422)). Contributed by @alunturner.
  * Implement MSC3952: intentional mentions ([\#9983](https://github.com/matrix-org/matrix-react-sdk/pull/9983)).
  * Implement MSC3973: Search users in the user directory with the Widget API ([\#10269](https://github.com/matrix-org/matrix-react-sdk/pull/10269)). Contributed by @dhenneke.
  * Permalinks to message are now displayed as pills ([\#10392](https://github.com/matrix-org/matrix-react-sdk/pull/10392)). Fixes vector-im/element-web#24751 and vector-im/element-web#24706.
  * Show search,dial,explore in filterContainer if "UIComponent.filterContainer" is enabled ([\#10381](https://github.com/matrix-org/matrix-react-sdk/pull/10381)). Contributed by @maheichyk.
  * Increase space panel collapse clickable area ([\#6084](https://github.com/matrix-org/matrix-react-sdk/pull/6084)). Fixes vector-im/element-web#17379. Contributed by @jaiwanth-v.
  * Add fallback for replies to Polls ([\#10380](https://github.com/matrix-org/matrix-react-sdk/pull/10380)). Fixes vector-im/element-web#24197. Contributed by @kerryarchibald.
  * Permalinks to rooms and users are now pillified ([\#10388](https://github.com/matrix-org/matrix-react-sdk/pull/10388)). Fixes vector-im/element-web#24825.
  * Poll history -  access poll history from room settings ([\#10356](https://github.com/matrix-org/matrix-react-sdk/pull/10356)). Contributed by @kerryarchibald.
  * Add API params to mute audio and/or video in Jitsi calls by default ([\#10376](https://github.com/matrix-org/matrix-react-sdk/pull/10376)). Contributed by @dhenneke.
  * Notifications: inline error message on notifications saving error ([\#10288](https://github.com/matrix-org/matrix-react-sdk/pull/10288)). Contributed by @kerryarchibald.
  * Support dynamic room predecessor in SpaceProvider ([\#10348](https://github.com/matrix-org/matrix-react-sdk/pull/10348)). Contributed by @andybalaam.
  * Support dynamic room predecessors for RoomProvider ([\#10346](https://github.com/matrix-org/matrix-react-sdk/pull/10346)). Contributed by @andybalaam.
  * Support dynamic room predecessors in OwnBeaconStore ([\#10339](https://github.com/matrix-org/matrix-react-sdk/pull/10339)). Contributed by @andybalaam.
  * Support dynamic room predecessors in ForwardDialog ([\#10344](https://github.com/matrix-org/matrix-react-sdk/pull/10344)). Contributed by @andybalaam.
  * Support dynamic room predecessors in SpaceHierarchy ([\#10341](https://github.com/matrix-org/matrix-react-sdk/pull/10341)). Contributed by @andybalaam.
  * Support dynamic room predecessors in AddExistingToSpaceDialog ([\#10342](https://github.com/matrix-org/matrix-react-sdk/pull/10342)). Contributed by @andybalaam.
  * Support dynamic room predecessors in leave-behaviour ([\#10340](https://github.com/matrix-org/matrix-react-sdk/pull/10340)). Contributed by @andybalaam.
  * Support dynamic room predecessors in StopGapWidgetDriver ([\#10338](https://github.com/matrix-org/matrix-react-sdk/pull/10338)). Contributed by @andybalaam.
  * Support dynamic room predecessors in WidgetLayoutStore ([\#10326](https://github.com/matrix-org/matrix-react-sdk/pull/10326)). Contributed by @andybalaam.
  * Support dynamic room predecessors in SpaceStore ([\#10332](https://github.com/matrix-org/matrix-react-sdk/pull/10332)). Contributed by @andybalaam.
  * Sync polls push rules on changes to account_data ([\#10287](https://github.com/matrix-org/matrix-react-sdk/pull/10287)). Contributed by @kerryarchibald.
  * Support dynamic room predecessors in BreadcrumbsStore ([\#10295](https://github.com/matrix-org/matrix-react-sdk/pull/10295)). Contributed by @andybalaam.
  * Improved a11y for Field feedback and Secure Phrase input ([\#10320](https://github.com/matrix-org/matrix-react-sdk/pull/10320)). Contributed by @Sebbones.
  * Support dynamic room predecessors in RoomNotificationStateStore ([\#10297](https://github.com/matrix-org/matrix-react-sdk/pull/10297)). Contributed by @andybalaam.
  [#]# 🐛 Bug Fixes
  * Run build_linux in docker using an older glibc ([\#599](https://github.com/vector-im/element-desktop/pull/599)). Fixes vector-im/element-web#24981.
  * Use a newly generated access_token while joining Jitsi ([\#24646](https://github.com/vector-im/element-web/pull/24646)). Fixes vector-im/element-web#24687. Contributed by @emrahcom.
  * Fix cloudflare action pointing at commit hash instead of tag ([\#24777](https://github.com/vector-im/element-web/pull/24777)). Contributed by @justjanne.
  * Allow editing with RTE to overflow for autocomplete visibility ([\#10499](https://github.com/matrix-org/matrix-react-sdk/pull/10499)). Contributed by @alunturner.
  * Added auto focus to Github URL on opening of debug logs modal ([\#10479](https://github.com/matrix-org/matrix-react-sdk/pull/10479)). Contributed by @ShivamSpm.
  * Fix detection of encryption for all users in a room ([\#10487](https://github.com/matrix-org/matrix-react-sdk/pull/10487)). Fixes vector-im/element-web#24995.
  * Properly generate mentions when editing a reply with MSC3952 ([\#10486](https://github.com/matrix-org/matrix-react-sdk/pull/10486)). Fixes vector-im/element-web#24924. Contributed by @kerryarchibald.
  * Improve performance of rendering a room with many hidden events ([\#10131](https://github.com/matrix-org/matrix-react-sdk/pull/10131)). Contributed by @andybalaam.
  * Prevent future date selection in jump to date ([\#10419](https://github.com/matrix-org/matrix-react-sdk/pull/10419)). Fixes vector-im/element-web#20800. Contributed by @MadLittleMods.
  * Add aria labels to message search bar to improve accessibility ([\#10476](https://github.com/matrix-org/matrix-react-sdk/pull/10476)). Fixes vector-im/element-web#24921.
  * Fix decryption failure bar covering the timeline ([\#10360](https://github.com/matrix-org/matrix-react-sdk/pull/10360)). Fixes vector-im/element-web#24780 vector-im/element-web#24074 and vector-im/element-web#24183. Contributed by @luixxiul.
  * Improve profile picture settings accessibility ([\#10470](https://github.com/matrix-org/matrix-react-sdk/pull/10470)). Fixes vector-im/element-web#24919.
  * Handle group call redaction ([\#10465](https://github.com/matrix-org/matrix-react-sdk/pull/10465)).
  * Display relative timestamp for threads on the same calendar day ([\#10399](https://github.com/matrix-org/matrix-react-sdk/pull/10399)). Fixes vector-im/element-web#24841. Contributed by @kerryarchibald.
  * Fix timeline list and paragraph display issues ([\#10424](https://github.com/matrix-org/matrix-react-sdk/pull/10424)). Fixes vector-im/element-web#24602. Contributed by @alunturner.
  * Use unique keys for voice broadcast pips ([\#10457](https://github.com/matrix-org/matrix-react-sdk/pull/10457)). Fixes vector-im/element-web#24959.
  * Fix "show read receipts sent by other users" not applying to threads ([\#10445](https://github.com/matrix-org/matrix-react-sdk/pull/10445)). Fixes vector-im/element-web#24910.
  * Fix joining public rooms without aliases in search dialog ([\#10437](https://github.com/matrix-org/matrix-react-sdk/pull/10437)). Fixes vector-im/element-web#23937.
  * Add input validation for `m.direct` in `DMRoomMap` ([\#10436](https://github.com/matrix-org/matrix-react-sdk/pull/10436)). Fixes vector-im/element-web#24909.
  * Reduce height reserved for "collapse" button's line on IRC layout ([\#10211](https://github.com/matrix-org/matrix-react-sdk/pull/10211)). Fixes vector-im/element-web#24605. Contributed by @luixxiul.
  * Fix `creatorUserId is required` error when opening sticker picker ([\#10423](https://github.com/matrix-org/matrix-react-sdk/pull/10423)).
  * Fix block/inline Element descendants error noise in `NewRoomIntro.tsx` ([\#10412](https://github.com/matrix-org/matrix-react-sdk/pull/10412)). Contributed by @MadLittleMods.
  * Fix profile resizer to make first character of a line selectable in IRC layout ([\#10396](https://github.com/matrix-org/matrix-react-sdk/pull/10396)). Fixes vector-im/element-web#14764. Contributed by @luixxiul.
  * Ensure space between wrapped lines of room name on IRC layout ([\#10188](https://github.com/matrix-org/matrix-react-sdk/pull/10188)). Fixes vector-im/element-web#24742. Contributed by @luixxiul.
  * Remove unreadable alt attribute from the room status bar warning icon (nonsense to screenreaders) ([\#10402](https://github.com/matrix-org/matrix-react-sdk/pull/10402)). Contributed by @MadLittleMods.
  * Fix big date separators when jump to date is enabled ([\#10404](https://github.com/matrix-org/matrix-react-sdk/pull/10404)). Fixes vector-im/element-web#22969. Contributed by @MadLittleMods.
  * Fixes user authentication when registering via the module API ([\#10257](https://github.com/matrix-org/matrix-react-sdk/pull/10257)). Contributed by @maheichyk.
  * Handle more edge cases in Space Hierarchy ([\#10280](https://github.com/matrix-org/matrix-react-sdk/pull/10280)). Contributed by @justjanne.
  * Further improve performance with lots of hidden events ([\#10353](https://github.com/matrix-org/matrix-react-sdk/pull/10353)). Fixes vector-im/element-web#24480. Contributed by @andybalaam.
  * Respect user cancelling upload flow by dismissing spinner ([\#10373](https://github.com/matrix-org/matrix-react-sdk/pull/10373)). Fixes vector-im/element-web#24667.
  * When starting a DM, the end-to-end encryption status icon does now only appear if the DM can be encrypted ([\#10394](https://github.com/matrix-org/matrix-react-sdk/pull/10394)). Fixes vector-im/element-web#24397.
  * Fix `[object Object]` in feedback metadata ([\#10390](https://github.com/matrix-org/matrix-react-sdk/pull/10390)).
  * Fix pinned messages card saying nothing pinned while loading ([\#10385](https://github.com/matrix-org/matrix-react-sdk/pull/10385)). Fixes vector-im/element-web#24615.
  * Fix import e2e key dialog staying disabled after paste ([\#10375](https://github.com/matrix-org/matrix-react-sdk/pull/10375)). Fixes vector-im/element-web#24818.
  * Show all labs even if incompatible, with appropriate tooltip explaining requirements ([\#10369](https://github.com/matrix-org/matrix-react-sdk/pull/10369)). Fixes vector-im/element-web#24813.
  * Fix UIFeature.Registration not applying to all paths ([\#10371](https://github.com/matrix-org/matrix-react-sdk/pull/10371)). Fixes vector-im/element-web#24814.
  * Clicking on a user pill does now only open the profile in the right panel and no longer navigates to the home view. ([\#10359](https://github.com/matrix-org/matrix-react-sdk/pull/10359)). Fixes vector-im/element-web#24797.
  * Fix start DM with pending third party invite ([\#10347](https://github.com/matrix-org/matrix-react-sdk/pull/10347)). Fixes vector-im/element-web#24781.
  * Fix long display name overflowing reply tile on IRC layout ([\#10343](https://github.com/matrix-org/matrix-react-sdk/pull/10343)). Fixes vector-im/element-web#24738. Contributed by @luixxiul.
  * Display redacted body on ThreadView in the same way as normal messages ([\#9016](https://github.com/matrix-org/matrix-react-sdk/pull/9016)). Fixes vector-im/element-web#24729. Contributed by @luixxiul.
  * Handle more edge cases in ACL updates ([\#10279](https://github.com/matrix-org/matrix-react-sdk/pull/10279)). Contributed by @justjanne.
  * Allow parsing png files to fail if thumbnailing is successful ([\#10308](https://github.com/matrix-org/matrix-react-sdk/pull/10308)).
* Tue Mar 28 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.26
  [#]# 🐛 Bug Fixes
  * Changes for matrix-js-sdk v24.0.0
  * Changes for matrix-react-sdk v3.69.0
* Tue Mar 28 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.25
  [#]# ✨ Features
  * Remove experimental PWA support for Firefox and Safari ([\#24630](https://github.com/vector-im/element-web/pull/24630)).
  * Only allow to start a DM with one email if encryption by default is enabled ([\#10253](https://github.com/matrix-org/matrix-react-sdk/pull/10253)). Fixes vector-im/element-web#23133.
  * DM rooms are now encrypted if encryption by default is enabled and only inviting a single email address. Any action in the result DM room will be blocked until the other has joined. ([\#10229](https://github.com/matrix-org/matrix-react-sdk/pull/10229)).
  * Reduce bottom margin of ReplyChain on compact modern layout ([\#8972](https://github.com/matrix-org/matrix-react-sdk/pull/8972)). Fixes vector-im/element-web#22748. Contributed by @luixxiul.
  * Support for v2 of MSC3903 ([\#10165](https://github.com/matrix-org/matrix-react-sdk/pull/10165)). Contributed by @hughns.
  * When starting a DM, existing rooms with pending third-party invites will be reused. ([\#10256](https://github.com/matrix-org/matrix-react-sdk/pull/10256)). Fixes vector-im/element-web#23139.
  * Polls push rules: synchronise poll rules with message rules ([\#10263](https://github.com/matrix-org/matrix-react-sdk/pull/10263)). Contributed by @kerryarchibald.
  * New verification request toast button labels ([\#10259](https://github.com/matrix-org/matrix-react-sdk/pull/10259)).
  * Remove padding around integration manager iframe ([\#10148](https://github.com/matrix-org/matrix-react-sdk/pull/10148)).
  * Fix block code styling in rich text editor ([\#10246](https://github.com/matrix-org/matrix-react-sdk/pull/10246)). Contributed by @alunturner.
  * Poll history: fetch more poll history ([\#10235](https://github.com/matrix-org/matrix-react-sdk/pull/10235)). Contributed by @kerryarchibald.
  * Sort short/exact emoji matches before longer incomplete matches ([\#10212](https://github.com/matrix-org/matrix-react-sdk/pull/10212)). Fixes vector-im/element-web#23210. Contributed by @grimhilt.
  * Poll history: detail screen ([\#10172](https://github.com/matrix-org/matrix-react-sdk/pull/10172)). Contributed by @kerryarchibald.
  * Provide a more detailed error message than "No known servers" ([\#6048](https://github.com/matrix-org/matrix-react-sdk/pull/6048)). Fixes vector-im/element-web#13247. Contributed by @aaronraimist.
  * Say when a call was answered from a different device ([\#10224](https://github.com/matrix-org/matrix-react-sdk/pull/10224)).
  * Widget permissions customizations using module api ([\#10121](https://github.com/matrix-org/matrix-react-sdk/pull/10121)). Contributed by @maheichyk.
  * Fix copy button icon overlapping with copyable text ([\#10227](https://github.com/matrix-org/matrix-react-sdk/pull/10227)). Contributed by @Adesh-Pandey.
  * Support joining non-peekable rooms via the module API ([\#10154](https://github.com/matrix-org/matrix-react-sdk/pull/10154)). Contributed by @maheichyk.
  * The "new login" toast does now display the same device information as in the settings. "No" does now open the device settings. "Yes, it was me" dismisses the toast. ([\#10200](https://github.com/matrix-org/matrix-react-sdk/pull/10200)).
  * Do not prompt for a password when doing a „reset all“ after login ([\#10208](https://github.com/matrix-org/matrix-react-sdk/pull/10208)).
  [#]# 🐛 Bug Fixes
  * Fix macOS notarisation using keychain credentials ([\#557](https://github.com/vector-im/element-desktop/pull/557)).
  * Let electron-builder correctly set StartupWMClass ([\#526](https://github.com/vector-im/element-desktop/pull/526)). Fixes vector-im/element-web#13780.
  * Fix incorrect copy in space creation flow ([\#10296](https://github.com/matrix-org/matrix-react-sdk/pull/10296)). Fixes vector-im/element-web#24741.
  * Fix space settings dialog having rogue title tooltip ([\#10293](https://github.com/matrix-org/matrix-react-sdk/pull/10293)). Fixes vector-im/element-web#24740.
  * Show spinner when starting a DM from the user profile (right panel) ([\#10290](https://github.com/matrix-org/matrix-react-sdk/pull/10290)).
  * Reduce height of toggle on expanded view source event ([\#10283](https://github.com/matrix-org/matrix-react-sdk/pull/10283)). Fixes vector-im/element-web#22873. Contributed by @luixxiul.
  * Pillify http and non-prefixed matrix.to links ([\#10277](https://github.com/matrix-org/matrix-react-sdk/pull/10277)). Fixes vector-im/element-web#20844.
  * Fix some features not being configurable via `features` ([\#10276](https://github.com/matrix-org/matrix-react-sdk/pull/10276)).
  * Fix starting a DM from the right panel in some cases ([\#10278](https://github.com/matrix-org/matrix-react-sdk/pull/10278)). Fixes vector-im/element-web#24722.
  * Align info EventTile and normal EventTile on IRC layout ([\#10197](https://github.com/matrix-org/matrix-react-sdk/pull/10197)). Fixes vector-im/element-web#22782. Contributed by @luixxiul.
  * Fix blowout of waveform of the voice message player on narrow UI ([\#8861](https://github.com/matrix-org/matrix-react-sdk/pull/8861)). Fixes vector-im/element-web#22604. Contributed by @luixxiul.
  * Fix the hidden view source toggle on IRC layout ([\#10266](https://github.com/matrix-org/matrix-react-sdk/pull/10266)). Fixes vector-im/element-web#22872. Contributed by @luixxiul.
  * Fix buttons on the room header being compressed due to long room name ([\#10155](https://github.com/matrix-org/matrix-react-sdk/pull/10155)). Contributed by @luixxiul.
  * Use the room avatar as a placeholder in calls ([\#10231](https://github.com/matrix-org/matrix-react-sdk/pull/10231)).
  * Fix calls showing as 'connecting' after hangup ([\#10223](https://github.com/matrix-org/matrix-react-sdk/pull/10223)).
  * Prevent multiple Jitsi calls started at the same time ([\#10183](https://github.com/matrix-org/matrix-react-sdk/pull/10183)). Fixes vector-im/element-web#23009.
  * Make localization keys compatible with agglutinative and/or SOV type languages ([\#10159](https://github.com/matrix-org/matrix-react-sdk/pull/10159)). Contributed by @luixxiul.
* Tue Feb 14 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.23
  [#]# ✨ Features
  * Description of QR code sign in labs feature ([\#23513](https://github.com/vector-im/element-web/pull/23513)). Contributed by @hughns.
  * Add option to find own location in map views ([\#10083](https://github.com/matrix-org/matrix-react-sdk/pull/10083)).
  * Render poll end events in timeline ([\#10027](https://github.com/matrix-org/matrix-react-sdk/pull/10027)). Contributed by @kerryarchibald.
  * Indicate unread messages in tab title ([\#10096](https://github.com/matrix-org/matrix-react-sdk/pull/10096)). Contributed by @tnt7864.
  * Open message in editing mode when keyboard up is pressed (RTE) ([\#10079](https://github.com/matrix-org/matrix-react-sdk/pull/10079)). Contributed by @florianduros.
  * Hide superseded rooms from the room list using dynamic room predecessors ([\#10068](https://github.com/matrix-org/matrix-react-sdk/pull/10068)). Contributed by @andybalaam.
  * Support MSC3946 in RoomListStore ([\#10054](https://github.com/matrix-org/matrix-react-sdk/pull/10054)). Fixes vector-im/element-web#24325. Contributed by @andybalaam.
  * Auto focus security key field ([\#10048](https://github.com/matrix-org/matrix-react-sdk/pull/10048)).
  * use Poll model with relations API in poll rendering ([\#9877](https://github.com/matrix-org/matrix-react-sdk/pull/9877)). Contributed by @kerryarchibald.
  * Support MSC3946 in the RoomCreate tile ([\#10041](https://github.com/matrix-org/matrix-react-sdk/pull/10041)). Fixes vector-im/element-web#24323. Contributed by @andybalaam.
  * Update labs flag description for RTE ([\#10058](https://github.com/matrix-org/matrix-react-sdk/pull/10058)). Contributed by @florianduros.
  * Change ul list style to disc when editing message ([\#10043](https://github.com/matrix-org/matrix-react-sdk/pull/10043)). Contributed by @alunturner.
  * Improved click detection within PiP windows ([\#10040](https://github.com/matrix-org/matrix-react-sdk/pull/10040)). Fixes vector-im/element-web#24371.
  * Add RTE keyboard navigation in editing ([\#9980](https://github.com/matrix-org/matrix-react-sdk/pull/9980)). Fixes vector-im/element-web#23621. Contributed by @florianduros.
  * Paragraph integration for rich text editor ([\#10008](https://github.com/matrix-org/matrix-react-sdk/pull/10008)). Contributed by @alunturner.
  * Add  indentation increasing/decreasing to RTE ([\#10034](https://github.com/matrix-org/matrix-react-sdk/pull/10034)). Contributed by @florianduros.
  * Add ignore user confirmation dialog ([\#6116](https://github.com/matrix-org/matrix-react-sdk/pull/6116)). Fixes vector-im/element-web#14746.
  * Use monospace font for room, message IDs in View Source modal ([\#9956](https://github.com/matrix-org/matrix-react-sdk/pull/9956)). Fixes vector-im/element-web#21937. Contributed by @paragpoddar.
  * Implement MSC3946 for AdvancedRoomSettingsTab ([\#9995](https://github.com/matrix-org/matrix-react-sdk/pull/9995)). Fixes vector-im/element-web#24322. Contributed by @andybalaam.
  * Implementation of MSC3824 to make the client OIDC-aware ([\#8681](https://github.com/matrix-org/matrix-react-sdk/pull/8681)). Contributed by @hughns.
  * Improves a11y for avatar uploads ([\#9985](https://github.com/matrix-org/matrix-react-sdk/pull/9985)). Contributed by @GoodGuyMarco.
  * Add support for [token authenticated registration](https ([\#7275](https://github.com/matrix-org/matrix-react-sdk/pull/7275)). Fixes vector-im/element-web#18931. Contributed by @govynnus.
  [#]# 🐛 Bug Fixes
  * Update to Electron 22.2.0 - fix tray icons in Linux ([\#530](https://github.com/vector-im/element-desktop/pull/530)). Fixes vector-im/element-web#23993.
  * Jitsi requests 'requires_client' capability if auth token is provided ([\#24294](https://github.com/vector-im/element-web/pull/24294)). Contributed by @maheichyk.
  * Remove duplicate white space characters from translation keys ([\#10152](https://github.com/matrix-org/matrix-react-sdk/pull/10152)). Contributed by @luixxiul.
  * Fix the caption of new sessions manager on Labs settings page for localization ([\#10143](https://github.com/matrix-org/matrix-react-sdk/pull/10143)). Contributed by @luixxiul.
  * Prevent start another DM with a user if one already exists ([\#10127](https://github.com/matrix-org/matrix-react-sdk/pull/10127)). Fixes vector-im/element-web#23138.
  * Remove white space characters before the horizontal ellipsis ([\#10130](https://github.com/matrix-org/matrix-react-sdk/pull/10130)). Contributed by @luixxiul.
  * Fix Selectable Text on 'Delete All' and 'Retry All' Buttons ([\#10128](https://github.com/matrix-org/matrix-react-sdk/pull/10128)). Fixes vector-im/element-web#23232. Contributed by @akshattchhabra.
  * Correctly Identify emoticons ([\#10108](https://github.com/matrix-org/matrix-react-sdk/pull/10108)). Fixes vector-im/element-web#19472. Contributed by @adarsh-sgh.
  * Should open new 1:1 chat room after leaving the old one ([\#9880](https://github.com/matrix-org/matrix-react-sdk/pull/9880)). Contributed by @ahmadkadri.
  * Remove a redundant white space ([\#10129](https://github.com/matrix-org/matrix-react-sdk/pull/10129)). Contributed by @luixxiul.
  * Fix a crash when removing persistent widgets (updated) ([\#10099](https://github.com/matrix-org/matrix-react-sdk/pull/10099)). Fixes vector-im/element-web#24412. Contributed by @andybalaam.
  * Fix wrongly grouping 3pid invites into a single repeated transition ([\#10087](https://github.com/matrix-org/matrix-react-sdk/pull/10087)). Fixes vector-im/element-web#24432.
  * Fix scrollbar colliding with checkbox in add to space section ([\#10093](https://github.com/matrix-org/matrix-react-sdk/pull/10093)). Fixes vector-im/element-web#23189. Contributed by @Arnabdaz.
  * Add a whitespace character after 'broadcast?' ([\#10097](https://github.com/matrix-org/matrix-react-sdk/pull/10097)). Contributed by @luixxiul.
  * Seekbar in broadcast PiP view is now updated when switching between different broadcasts ([\#10072](https://github.com/matrix-org/matrix-react-sdk/pull/10072)). Fixes vector-im/element-web#24415.
  * Add border to "reject" button on room preview card for clickable area indication. It fixes vector-im/element-web#22623 ([\#9205](https://github.com/matrix-org/matrix-react-sdk/pull/9205)). Contributed by @gefgu.
  * Element-R: fix rageshages ([\#10081](https://github.com/matrix-org/matrix-react-sdk/pull/10081)). Fixes vector-im/element-web#24430.
  * Fix markdown paragraph display in timeline ([\#10071](https://github.com/matrix-org/matrix-react-sdk/pull/10071)). Fixes vector-im/element-web#24419. Contributed by @alunturner.
  * Prevent the remaining broadcast time from being exceeded ([\#10070](https://github.com/matrix-org/matrix-react-sdk/pull/10070)).
  * Fix cursor position when new line is created by pressing enter (RTE) ([\#10064](https://github.com/matrix-org/matrix-react-sdk/pull/10064)). Contributed by @florianduros.
  * Ensure room is actually in space hierarchy when resolving its latest version ([\#10010](https://github.com/matrix-org/matrix-react-sdk/pull/10010)).
  * Fix new line for inline code ([\#10062](https://github.com/matrix-org/matrix-react-sdk/pull/10062)). Contributed by @florianduros.
  * Member avatars without canvas ([\#9990](https://github.com/matrix-org/matrix-react-sdk/pull/9990)). Contributed by @clarkf.
  * Apply more general fix for base avatar regressions ([\#10045](https://github.com/matrix-org/matrix-react-sdk/pull/10045)). Fixes vector-im/element-web#24382 and vector-im/element-web#24370.
  * Replace list, code block and quote icons by new icons ([\#10035](https://github.com/matrix-org/matrix-react-sdk/pull/10035)). Contributed by @florianduros.
  * fix regional emojis converted to flags ([\#9294](https://github.com/matrix-org/matrix-react-sdk/pull/9294)). Fixes vector-im/element-web#19000. Contributed by @grimhilt.
  * resolved emoji description text overflowing issue ([\#10028](https://github.com/matrix-org/matrix-react-sdk/pull/10028)). Contributed by @fahadNoufal.
  * Fix MessageEditHistoryDialog crashing on complex input ([\#10018](https://github.com/matrix-org/matrix-react-sdk/pull/10018)). Fixes vector-im/element-web#23665. Contributed by @clarkf.
  * Unify unread notification state determination ([\#9941](https://github.com/matrix-org/matrix-react-sdk/pull/9941)). Contributed by @clarkf.
  * Fix layout and visual regressions around default avatars ([\#10031](https://github.com/matrix-org/matrix-react-sdk/pull/10031)). Fixes vector-im/element-web#24375 and vector-im/element-web#24369.
  * Fix useUnreadNotifications exploding with falsey room, like in notif panel ([\#10030](https://github.com/matrix-org/matrix-react-sdk/pull/10030)). Fixes matrix-org/element-web-rageshakes#19334.
  * Fix "[object Promise]" appearing in HTML exports ([\#9975](https://github.com/matrix-org/matrix-react-sdk/pull/9975)). Fixes vector-im/element-web#24272. Contributed by @clarkf.
  * changing the color of message time stamp ([\#10016](https://github.com/matrix-org/matrix-react-sdk/pull/10016)). Contributed by @nawarajshah.
  * Fix link creation with backward selection ([\#9986](https://github.com/matrix-org/matrix-react-sdk/pull/9986)). Fixes vector-im/element-web#24315. Contributed by @florianduros.
  * Misaligned reply preview in thread composer #23396 ([\#9977](https://github.com/matrix-org/matrix-react-sdk/pull/9977)). Fixes vector-im/element-web#23396. Contributed by @mustafa-kapadia1483.
* Fri Feb 10 2023 Sebastian Wagner <sebix@sebix.at>
- Version 1.11.22
  [#]# 🐛 Bug Fixes
  * Bump version number to fix problems upgrading from v1.11.21-rc.1
- Version 1.11.21
  [#]# ✨ Features
  * Move pin drop out of labs ([\#22993](https://github.com/vector-im/element-web/pull/22993)).
  * Quotes for rte ([\#9932](https://github.com/matrix-org/matrix-react-sdk/pull/9932)). Contributed by @alunturner.
  * Show the room name in the room header during calls ([\#9942](https://github.com/matrix-org/matrix-react-sdk/pull/9942)). Fixes vector-im/element-web#24268.
  * Add code blocks to rich text editor ([\#9921](https://github.com/matrix-org/matrix-react-sdk/pull/9921)). Contributed by @alunturner.
  * Add new style for inline code ([\#9936](https://github.com/matrix-org/matrix-react-sdk/pull/9936)). Contributed by @florianduros.
  * Add disabled button state to rich text editor ([\#9930](https://github.com/matrix-org/matrix-react-sdk/pull/9930)). Contributed by @alunturner.
  * Change the rageshake "app" for auto-rageshakes ([\#9909](https://github.com/matrix-org/matrix-react-sdk/pull/9909)).
  * Device manager - tweak settings display ([\#9905](https://github.com/matrix-org/matrix-react-sdk/pull/9905)). Contributed by @kerryarchibald.
  * Add list functionality to rich text editor ([\#9871](https://github.com/matrix-org/matrix-react-sdk/pull/9871)). Contributed by @alunturner.
  [#]# 🐛 Bug Fixes
  * Fix RTE focus behaviour in threads ([\#9969](https://github.com/matrix-org/matrix-react-sdk/pull/9969)). Fixes vector-im/element-web#23755. Contributed by @florianduros.
  * #22204 Issue: Centered File info in lightbox ([\#9971](https://github.com/matrix-org/matrix-react-sdk/pull/9971)). Fixes vector-im/element-web#22204. Contributed by @Spartan09.
  * Fix seekbar position for zero length audio ([\#9949](https://github.com/matrix-org/matrix-react-sdk/pull/9949)). Fixes vector-im/element-web#24248.
  * Allow thread panel to be closed after being opened from notification ([\#9937](https://github.com/matrix-org/matrix-react-sdk/pull/9937)). Fixes vector-im/element-web#23764 vector-im/element-web#23852 and vector-im/element-web#24213. Contributed by @justjanne.
  * Only highlight focused menu item if focus is supposed to be visible ([\#9945](https://github.com/matrix-org/matrix-react-sdk/pull/9945)). Fixes vector-im/element-web#23582.
  * Prevent call durations from breaking onto multiple lines ([\#9944](https://github.com/matrix-org/matrix-react-sdk/pull/9944)).
  * Tweak call lobby buttons to more closely match designs ([\#9943](https://github.com/matrix-org/matrix-react-sdk/pull/9943)).
  * Do not show a broadcast as live immediately after the recording has stopped ([\#9947](https://github.com/matrix-org/matrix-react-sdk/pull/9947)). Fixes vector-im/element-web#24233.
  * Clear the RTE before sending a message ([\#9948](https://github.com/matrix-org/matrix-react-sdk/pull/9948)). Contributed by @florianduros.
  * Fix {enter} press in RTE ([\#9927](https://github.com/matrix-org/matrix-react-sdk/pull/9927)). Contributed by @florianduros.
  * Fix the problem that the password reset email has to be confirmed twice ([\#9926](https://github.com/matrix-org/matrix-react-sdk/pull/9926)). Fixes vector-im/element-web#24226.
  * replace .at() with array.length-1 ([\#9933](https://github.com/matrix-org/matrix-react-sdk/pull/9933)). Fixes matrix-org/element-web-rageshakes#19281.
  * Fix broken threads list timestamp layout ([\#9922](https://github.com/matrix-org/matrix-react-sdk/pull/9922)). Fixes vector-im/element-web#24243 and vector-im/element-web#24191. Contributed by @justjanne.
  * Disable multiple messages when {enter} is pressed multiple times ([\#9929](https://github.com/matrix-org/matrix-react-sdk/pull/9929)). Fixes vector-im/element-web#24249. Contributed by @florianduros.
  * Fix logout devices when resetting the password ([\#9925](https://github.com/matrix-org/matrix-react-sdk/pull/9925)). Fixes vector-im/element-web#24228.
  * Fix: Poll replies overflow when not enough space ([\#9924](https://github.com/matrix-org/matrix-react-sdk/pull/9924)). Fixes vector-im/element-web#24227. Contributed by @kerryarchibald.
  * State event updates are not forwarded to the widget from invitation room ([\#9802](https://github.com/matrix-org/matrix-react-sdk/pull/9802)). Contributed by @maheichyk.
  * Fix error when viewing source of redacted events ([\#9914](https://github.com/matrix-org/matrix-react-sdk/pull/9914)). Fixes vector-im/element-web#24165. Contributed by @clarkf.
  * Replace outdated css attribute ([\#9912](https://github.com/matrix-org/matrix-react-sdk/pull/9912)). Fixes vector-im/element-web#24218. Contributed by @justjanne.
  * Clear isLogin theme override when user is no longer viewing login screens ([\#9911](https://github.com/matrix-org/matrix-react-sdk/pull/9911)). Fixes vector-im/element-web#23893.
  * Fix reply action in message context menu notif & file panels ([\#9895](https://github.com/matrix-org/matrix-react-sdk/pull/9895)). Fixes vector-im/element-web#23970.
  * Fix issue where thread dropdown would not show up correctly ([\#9872](https://github.com/matrix-org/matrix-react-sdk/pull/9872)). Fixes vector-im/element-web#24040. Contributed by @justjanne.
  * Fix unexpected composer growing ([\#9889](https://github.com/matrix-org/matrix-react-sdk/pull/9889)). Contributed by @florianduros.
  * Fix misaligned timestamps for thread roots which are emotes ([\#9875](https://github.com/matrix-org/matrix-react-sdk/pull/9875)). Fixes vector-im/element-web#23897. Contributed by @justjanne.
* Sat Feb  4 2023 Andreas Schneider <asn@cryptomilk.org>
- Some spec file cleanups
* Fri Jan 20 2023 Dominik Heidler <dheidler@suse.de>
- Version 1.11.20
  [#]# 🐛 Bug Fixes
  * (no effect on Element Desktop) (Part 2) fix crash on browsers that don't support `Array.at`
* Fri Dec 23 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.11.17
  [#]# 🚨 BREAKING CHANGES
  * This allows the update server to be entirely static, such as a CDN or object store, as defined at https ([\#461](https://github.com/vector-im/element-desktop/pull/461)).
  [#]# ✨ Features
  * Enable threads by default ([\#9736](https://github.com/matrix-org/matrix-react-sdk/pull/9736)). Fixes vector-im/element-web#19270 vector-im/element-web#21910 and vector-im/element-web#23946.
  * Add inline code formatting to rich text editor ([\#9720](https://github.com/matrix-org/matrix-react-sdk/pull/9720)).
  * Add emoji handling for plain text mode of the new rich text editor ([\#9727](https://github.com/matrix-org/matrix-react-sdk/pull/9727)).
  * Overlay virtual room call events into main timeline ([\#9626](https://github.com/matrix-org/matrix-react-sdk/pull/9626)). Fixes vector-im/element-web#22929.
  * Adds a new section under "Room Settings" > "Roles & Permissions" which adds the possibility to multiselect users from this room and grant them more permissions. ([\#9596](https://github.com/matrix-org/matrix-react-sdk/pull/9596)). Contributed by @GoodGuyMarco.
  * Add emoji handling for rich text mode ([\#9661](https://github.com/matrix-org/matrix-react-sdk/pull/9661)).
  * Add setting to hide bold notifications ([\#9705](https://github.com/matrix-org/matrix-react-sdk/pull/9705)).
  * Further password reset flow enhancements ([\#9662](https://github.com/matrix-org/matrix-react-sdk/pull/9662)).
  * Snooze the bulk unverified sessions reminder on dismiss ([\#9706](https://github.com/matrix-org/matrix-react-sdk/pull/9706)).
  * Honor advanced audio processing settings when recording voice messages ([\#9610](https://github.com/matrix-org/matrix-react-sdk/pull/9610)). Contributed by @MrAnno.
  * Improve the visual balance of bubble layout ([\#9704](https://github.com/matrix-org/matrix-react-sdk/pull/9704)).
  * Add config setting to disable bulk unverified sessions nag ([\#9657](https://github.com/matrix-org/matrix-react-sdk/pull/9657)).
  * Only display bulk unverified sessions nag when current sessions is verified ([\#9656](https://github.com/matrix-org/matrix-react-sdk/pull/9656)).
  * Separate labs and betas more clearly ([\#8969](https://github.com/matrix-org/matrix-react-sdk/pull/8969)). Fixes vector-im/element-web#22706.
  * Show user an error if we fail to create a DM for verification. ([\#9624](https://github.com/matrix-org/matrix-react-sdk/pull/9624)).
  [#]# 🐛 Bug Fixes
  * Prevent unnecessary m.direct updates ([\#9805](https://github.com/matrix-org/matrix-react-sdk/pull/9805)). Fixes vector-im/element-web#24059.
  * Fix checkForPreJoinUISI for thread roots ([\#9803](https://github.com/matrix-org/matrix-react-sdk/pull/9803)). Fixes vector-im/element-web#24054.
  * Load RTE components only when RTE labs is enabled ([\#9804](https://github.com/matrix-org/matrix-react-sdk/pull/9804)).
  * Fix issue where thread panel did not update correctly ([\#9746](https://github.com/matrix-org/matrix-react-sdk/pull/9746)). Fixes vector-im/element-web#23971.
  * Remove async call to get virtual room from room load ([\#9743](https://github.com/matrix-org/matrix-react-sdk/pull/9743)). Fixes vector-im/element-web#23968.
  * Check each thread for unread messages. ([\#9723](https://github.com/matrix-org/matrix-react-sdk/pull/9723)).
  * Device manage - handle sessions that don't support encryption ([\#9717](https://github.com/matrix-org/matrix-react-sdk/pull/9717)). Fixes vector-im/element-web#23722.
  * Fix hover state for formatting buttons (Rich text editor) (fix vector-im/element-web/issues/23832) ([\#9715](https://github.com/matrix-org/matrix-react-sdk/pull/9715)).
  * Don't allow group calls to be unterminated ([\#9710](https://github.com/matrix-org/matrix-react-sdk/pull/9710)).
  * Fix replies to emotes not showing as inline ([\#9707](https://github.com/matrix-org/matrix-react-sdk/pull/9707)). Fixes vector-im/element-web#23903.
  * Update copy of 'Change layout' button to match Element Call ([\#9703](https://github.com/matrix-org/matrix-react-sdk/pull/9703)).
  * Fix call splitbrains when switching between rooms ([\#9692](https://github.com/matrix-org/matrix-react-sdk/pull/9692)).
  * bugfix: fix an issue where the Notifier would incorrectly fire for non-timeline events ([\#9664](https://github.com/matrix-org/matrix-react-sdk/pull/9664)). Fixes vector-im/element-web#17263.
  * Fix power selector being wrongly disabled for admins themselves ([\#9681](https://github.com/matrix-org/matrix-react-sdk/pull/9681)). Fixes vector-im/element-web#23882.
  * Show day counts in call durations ([\#9641](https://github.com/matrix-org/matrix-react-sdk/pull/9641)).
* Fri Dec  2 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.11.15
  [#]# ✨ Features
  * Switch to notarytool ([\#440](https://github.com/vector-im/element-desktop/pull/440)).
  * Make clear notifications work with threads ([\#9575](https://github.com/matrix-org/matrix-react-sdk/pull/9575)). Fixes vector-im/element-web#23751.
  * Change "None" to "Off" in notification options ([\#9539](https://github.com/matrix-org/matrix-react-sdk/pull/9539)). Contributed by @Arnei.
  * Advanced audio processing settings ([\#8759](https://github.com/matrix-org/matrix-react-sdk/pull/8759)). Fixes vector-im/element-web#6278. Contributed by @MrAnno.
  * Add way to create a user notice via config.json ([\#9559](https://github.com/matrix-org/matrix-react-sdk/pull/9559)).
  * Improve design of the rich text editor ([\#9533](https://github.com/matrix-org/matrix-react-sdk/pull/9533)).
  * Enable user to zoom beyond image size ([\#5949](https://github.com/matrix-org/matrix-react-sdk/pull/5949)). Contributed by @jaiwanth-v.
  * Fix: Move "Leave Space" option to the bottom of space context menu ([\#9535](https://github.com/matrix-org/matrix-react-sdk/pull/9535)). Contributed by @hanadi92.
  [#]# 🐛 Bug Fixes
  * Fix encrypted message search indexing for non-default `--profile` instances. ([\#433](https://github.com/vector-im/element-desktop/pull/433)).
  * Make build scripts work on NixOS ([\#23740](https://github.com/vector-im/element-web/pull/23740)).
  * Fix integration manager `get_open_id_token` action and add E2E tests ([\#9520](https://github.com/matrix-org/matrix-react-sdk/pull/9520)).
  * Fix links being mangled by markdown processing ([\#9570](https://github.com/matrix-org/matrix-react-sdk/pull/9570)). Fixes vector-im/element-web#23743.
  * Fix: inline links selecting radio button ([\#9543](https://github.com/matrix-org/matrix-react-sdk/pull/9543)). Contributed by @hanadi92.
  * fix wrong error message in registration when phone number threepid is in use. ([\#9571](https://github.com/matrix-org/matrix-react-sdk/pull/9571)). Contributed by @bagvand.
  * Fix missing avatar for show current profiles ([\#9563](https://github.com/matrix-org/matrix-react-sdk/pull/9563)). Fixes vector-im/element-web#23733.
  * fix read receipts trickling down correctly ([\#9567](https://github.com/matrix-org/matrix-react-sdk/pull/9567)). Fixes vector-im/element-web#23746.
  * Resilience fix for homeserver without thread notification support ([\#9565](https://github.com/matrix-org/matrix-react-sdk/pull/9565)).
  * Don't switch to the home page needlessly after leaving a room ([\#9477](https://github.com/matrix-org/matrix-react-sdk/pull/9477)).
  * Differentiate download and decryption errors when showing images ([\#9562](https://github.com/matrix-org/matrix-react-sdk/pull/9562)). Fixes vector-im/element-web#3892.
  * Close context menu when a modal is opened to prevent user getting stuck ([\#9560](https://github.com/matrix-org/matrix-react-sdk/pull/9560)). Fixes vector-im/element-web#15610 and vector-im/element-web#10781.
  * Fix TimelineReset handling when no room associated ([\#9553](https://github.com/matrix-org/matrix-react-sdk/pull/9553)).
  * Always use current profile on thread events ([\#9524](https://github.com/matrix-org/matrix-react-sdk/pull/9524)). Fixes vector-im/element-web#23648.
  * Fix `ThreadView` tests not using thread flag ([\#9547](https://github.com/matrix-org/matrix-react-sdk/pull/9547)).
  * Fix regressions around media uploads failing and causing soft crashes ([\#9549](https://github.com/matrix-org/matrix-react-sdk/pull/9549)). Fixes matrix-org/element-web-rageshakes#16831, matrix-org/element-web-rageshakes#16824 matrix-org/element-web-rageshakes#16810 and vector-im/element-web#23641.
  * Handle deletion of `m.call` events ([\#9540](https://github.com/matrix-org/matrix-react-sdk/pull/9540)). Fixes vector-im/element-web#23663.
  * Fix /myroomavatar slash command ([\#9536](https://github.com/matrix-org/matrix-react-sdk/pull/9536)). Fixes matrix-org/synapse#14321.
  * Fix incorrect notification count after leaving a room with notifications ([\#9518](https://github.com/matrix-org/matrix-react-sdk/pull/9518)). Contributed by @Arnei.
* Wed Nov  2 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.11.13
  [#]# 🐛 Bug Fixes
  * Fix default behavior of Room.getBlacklistUnverifiedDevices ([\#2830](https://github.com/matrix-org/matrix-js-sdk/pull/2830)). Contributed by @duxovni.
  * Catch server versions API call exception when starting the client ([\#2828](https://github.com/matrix-org/matrix-js-sdk/pull/2828)). Fixes vector-im/element-web#23634.
  * Fix authedRequest including `Authorization: Bearer undefined` for password resets ([\#2822](https://github.com/matrix-org/matrix-js-sdk/pull/2822)). Fixes vector-im/element-web#23655.
* Wed Oct 12 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.11.10
  [#]# 🐛 Bug Fixes
  * Use correct default for notification silencing ([\#9388](https://github.com/matrix-org/matrix-react-sdk/pull/9388)). Fixes vector-im/element-web#23456.
* Tue Oct 11 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.11.9
  [#]#   Deprecations
  * Legacy Piwik config.json option `piwik.policy_url` is deprecated in favour of `privacy_policy_url`. Support will be removed in the next release.
  [#]# ✨ Features
  * Device manager - select all devices ([\#9330](https://github.com/matrix-org/matrix-react-sdk/pull/9330)). Contributed by @kerryarchibald.
  * New group call experience: Call tiles ([\#9332](https://github.com/matrix-org/matrix-react-sdk/pull/9332)).
  * Add Shift key to FormatQuote keyboard shortcut ([\#9298](https://github.com/matrix-org/matrix-react-sdk/pull/9298)). Contributed by @owi92.
  * Device manager - sign out of multiple sessions ([\#9325](https://github.com/matrix-org/matrix-react-sdk/pull/9325)). Contributed by @kerryarchibald.
  * Display push toggle for web sessions (MSC3890) ([\#9327](https://github.com/matrix-org/matrix-react-sdk/pull/9327)).
  * Add device notifications enabled switch ([\#9324](https://github.com/matrix-org/matrix-react-sdk/pull/9324)).
  * Implement push notification toggle in device detail ([\#9308](https://github.com/matrix-org/matrix-react-sdk/pull/9308)).
  * New group call experience: Starting and ending calls ([\#9318](https://github.com/matrix-org/matrix-react-sdk/pull/9318)).
  * New group call experience: Room header call buttons ([\#9311](https://github.com/matrix-org/matrix-react-sdk/pull/9311)).
  * Make device ID copyable in device list ([\#9297](https://github.com/matrix-org/matrix-react-sdk/pull/9297)). Contributed by @duxovni.
  * Use display name instead of user ID when rendering power events ([\#9295](https://github.com/matrix-org/matrix-react-sdk/pull/9295)).
  * Read receipts for threads ([\#9239](https://github.com/matrix-org/matrix-react-sdk/pull/9239)). Fixes vector-im/element-web#23191.
  [#]# 🐛 Bug Fixes
  * Use the correct sender key when checking shared secret ([\#2730](https://github.com/matrix-org/matrix-js-sdk/pull/2730)). Fixes vector-im/element-web#23374.
  * Fix device selection in pre-join screen for Element Call video rooms ([\#9321](https://github.com/matrix-org/matrix-react-sdk/pull/9321)). Fixes vector-im/element-web#23331.
  * Don't render a 1px high room topic if the room topic is empty ([\#9317](https://github.com/matrix-org/matrix-react-sdk/pull/9317)). Contributed by @Arnei.
  * Don't show feedback prompts when that UIFeature is disabled ([\#9305](https://github.com/matrix-org/matrix-react-sdk/pull/9305)). Fixes vector-im/element-web#23327.
  * Fix soft crash around unknown room pills ([\#9301](https://github.com/matrix-org/matrix-react-sdk/pull/9301)). Fixes matrix-org/element-web-rageshakes#15465.
  * Fix spaces feedback prompt wrongly showing when feedback is disabled ([\#9302](https://github.com/matrix-org/matrix-react-sdk/pull/9302)). Fixes vector-im/element-web#23314.
  * Fix tile soft crash in ReplyInThreadButton ([\#9300](https://github.com/matrix-org/matrix-react-sdk/pull/9300)). Fixes matrix-org/element-web-rageshakes#15493.
* Wed Oct  5 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- Fix FTBFS on ix86 and arm.
* Fri Sep 30 2022 Bruno Pitrus <brunopitrus@hotmail.com>
- Remove ExcludeArch, we build Electron for 32-bit too now.
* Wed Sep 28 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.11.8
  [#]# 🐛 Bug Fixes
  * Bump IDB crypto store version ([\#2705](https://github.com/matrix-org/matrix-js-sdk/pull/2705)).
* Wed Sep 28 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.11.7
  [#]# 🔒 Security
  * Fix for [CVE-2022-39249](https://cve.mitre.org/cgi-bin/cvekey.cgi?keyword=CVE%%2D2022%%2D39249)
  * Fix for [CVE-2022-39250](https://cve.mitre.org/cgi-bin/cvekey.cgi?keyword=CVE%%2D2022%%2D39250)
  * Fix for [CVE-2022-39251](https://cve.mitre.org/cgi-bin/cvekey.cgi?keyword=CVE%%2D2022%%2D39251)
  * Fix for [CVE-2022-39236](https://cve.mitre.org/cgi-bin/cvekey.cgi?keyword=CVE%%2D2022%%2D39236)
* Tue Sep 27 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.11.6
  [#]# ✨ Features
  * Element Call video rooms ([\#9267](https://github.com/matrix-org/matrix-react-sdk/pull/9267)).
  * Device manager - rename session ([\#9282](https://github.com/matrix-org/matrix-react-sdk/pull/9282)).
  * Allow widgets to read related events ([\#9210](https://github.com/matrix-org/matrix-react-sdk/pull/9210)). Contributed by @dhenneke.
  * Device manager - logout of other session ([\#9280](https://github.com/matrix-org/matrix-react-sdk/pull/9280)).
  * Device manager - logout current session ([\#9275](https://github.com/matrix-org/matrix-react-sdk/pull/9275)).
  * Device manager - verify other devices ([\#9274](https://github.com/matrix-org/matrix-react-sdk/pull/9274)).
  * Allow integration managers to remove users ([\#9211](https://github.com/matrix-org/matrix-react-sdk/pull/9211)).
  * Device manager - add verify current session button ([\#9252](https://github.com/matrix-org/matrix-react-sdk/pull/9252)).
  * Add NotifPanel dot back. ([\#9242](https://github.com/matrix-org/matrix-react-sdk/pull/9242)). Fixes vector-im/element-web#17641.
  * Implement MSC3575: Sliding Sync ([\#8328](https://github.com/matrix-org/matrix-react-sdk/pull/8328)).
  * Add the clipboard read permission for widgets ([\#9250](https://github.com/matrix-org/matrix-react-sdk/pull/9250)). Contributed by @stefanmuhle.
  [#]# 🐛 Bug Fixes
  * Make autocomplete pop-up wider in thread view ([\#9289](https://github.com/matrix-org/matrix-react-sdk/pull/9289)).
  * Fix soft crash around inviting invalid MXIDs in start DM on first message flow ([\#9281](https://github.com/matrix-org/matrix-react-sdk/pull/9281)). Fixes matrix-org/element-web-rageshakes#15060 and matrix-org/element-web-rageshakes#15140.
  * Fix in-reply-to previews not disappearing when swapping rooms ([\#9278](https://github.com/matrix-org/matrix-react-sdk/pull/9278)).
  * Fix invalid instanceof operand window.OffscreenCanvas ([\#9276](https://github.com/matrix-org/matrix-react-sdk/pull/9276)). Fixes vector-im/element-web#23275.
  * Fix memory leak caused by unremoved listener ([\#9273](https://github.com/matrix-org/matrix-react-sdk/pull/9273)).
  * Fix thumbnail generation when offscreen canvas fails ([\#9272](https://github.com/matrix-org/matrix-react-sdk/pull/9272)). Fixes vector-im/element-web#23265.
  * Prevent sliding sync from showing a room under multiple sublists ([\#9266](https://github.com/matrix-org/matrix-react-sdk/pull/9266)).
  * Fix tile crash around tooltipify links ([\#9270](https://github.com/matrix-org/matrix-react-sdk/pull/9270)). Fixes vector-im/element-web#23253.
  * Device manager - filter out nulled metadatas in device tile properly ([\#9251](https://github.com/matrix-org/matrix-react-sdk/pull/9251)).
  * Fix a sliding sync bug which could cause rooms to loop ([\#9268](https://github.com/matrix-org/matrix-react-sdk/pull/9268)).
  * Remove the grey gradient on images in bubbles in the timeline ([\#9241](https://github.com/matrix-org/matrix-react-sdk/pull/9241)). Fixes vector-im/element-web#21651.
  * Fix html export not including images ([\#9260](https://github.com/matrix-org/matrix-react-sdk/pull/9260)). Fixes vector-im/element-web#22059.
  * Fix possible soft crash from a race condition in space hierarchies ([\#9254](https://github.com/matrix-org/matrix-react-sdk/pull/9254)). Fixes matrix-org/element-web-rageshakes#15225.
  * Disable all types of autocorrect, -complete, -capitalize, etc on Spotlight's search field ([\#9259](https://github.com/matrix-org/matrix-react-sdk/pull/9259)).
  * Handle M_INVALID_USERNAME on /register/available ([\#9237](https://github.com/matrix-org/matrix-react-sdk/pull/9237)). Fixes vector-im/element-web#23161.
  * Fix issue with quiet zone around QR code ([\#9243](https://github.com/matrix-org/matrix-react-sdk/pull/9243)). Fixes vector-im/element-web#23199.
* Fri Sep 23 2022 Dominik Heidler <dheidler@suse.de>
- Fix for boo#1203675
* Wed Sep 14 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.11.5
  * Features
  * Device manager - hide unverified security recommendation when only current session is unverified ([\#9228](https://github.com/matrix-org/matrix-react-sdk/pull/9228)). Contributed by @kerryarchibald.
  * Device manager - scroll to filtered list from security recommendations ([\#9227](https://github.com/matrix-org/matrix-react-sdk/pull/9227)). Contributed by @kerryarchibald.
  * Device manager - updated dropdown style in filtered device list ([\#9226](https://github.com/matrix-org/matrix-react-sdk/pull/9226)). Contributed by @kerryarchibald.
  * Device manager - device type and verification icons on device tile ([\#9197](https://github.com/matrix-org/matrix-react-sdk/pull/9197)). Contributed by @kerryarchibald.
  * Bug Fixes
  * Description of DM room with more than two other people is now being displayed correctly ([\#9231](https://github.com/matrix-org/matrix-react-sdk/pull/9231)). Fixes #23094.
  * Fix voice messages with multiple composers ([\#9208](https://github.com/matrix-org/matrix-react-sdk/pull/9208)). Fixes #23023. Contributed by @grimhilt.
  * Fix suggested rooms going missing ([\#9236](https://github.com/matrix-org/matrix-react-sdk/pull/9236)). Fixes #23190.
  * Fix tooltip infinitely recursing ([\#9235](https://github.com/matrix-org/matrix-react-sdk/pull/9235)). Fixes matrix-org/element-web-rageshakes#15107, matrix-org/element-web-rageshakes#15093 matrix-org/element-web-rageshakes#15092 and matrix-org/element-web-rageshakes#15077.
  * Fix plain text export saving ([\#9230](https://github.com/matrix-org/matrix-react-sdk/pull/9230)). Contributed by @jryans.
  * Add missing space in SecurityRoomSettingsTab ([\#9222](https://github.com/matrix-org/matrix-react-sdk/pull/9222)). Contributed by @gefgu.
  * Make use of js-sdk roomNameGenerator to handle i18n for generated room names ([\#9209](https://github.com/matrix-org/matrix-react-sdk/pull/9209)). Fixes #21369.
  * Fix progress bar regression throughout the app ([\#9219](https://github.com/matrix-org/matrix-react-sdk/pull/9219)). Fixes #23121.
  * Reuse empty string & space string logic for event types in devtools ([\#9218](https://github.com/matrix-org/matrix-react-sdk/pull/9218)). Fixes #23115.
* Thu Sep  1 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.11.4
- Fixes for CVE-2022-36059 and CVE-2022-36060
* Wed Aug  3 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.11.2
  * Features
  * Live location share -  focus on user location on list item click ([\#9051](https://github.com/matrix-org/matrix-react-sdk/pull/9051)). Contributed by @kerryarchibald.
  * Live location sharing - don't trigger unread counts for beacon location events ([\#9071](https://github.com/matrix-org/matrix-react-sdk/pull/9071)). Contributed by @kerryarchibald.
  * Support for sending voice messages as replies and in threads ([\#9097](https://github.com/matrix-org/matrix-react-sdk/pull/9097)). Fixes #22031.
  * Add `Reply in thread` button to the right-click message context-menu ([\#9004](https://github.com/matrix-org/matrix-react-sdk/pull/9004)). Fixes #22745.
  * Starred_Messages_Feature_Contd_II/Outreachy ([\#9086](https://github.com/matrix-org/matrix-react-sdk/pull/9086)).
  * Use "frequently used emojis" for autocompletion in composer ([\#8998](https://github.com/matrix-org/matrix-react-sdk/pull/8998)). Fixes #18978. Contributed by @grimhilt.
  * Improve clickability of view source event toggle button  ([\#9068](https://github.com/matrix-org/matrix-react-sdk/pull/9068)). Fixes #21856. Contributed by @luixxiul.
  * Improve clickability of "collapse" link button on bubble layout ([\#9037](https://github.com/matrix-org/matrix-react-sdk/pull/9037)). Fixes #22864. Contributed by @luixxiul.
  * Starred_Messages_Feature/Outreachy ([\#8842](https://github.com/matrix-org/matrix-react-sdk/pull/8842)).
  * Implement Use Case Selection screen ([\#8984](https://github.com/matrix-org/matrix-react-sdk/pull/8984)). Contributed by @justjanne.
  * Live location share - handle insufficient permissions in location sharing ([\#9047](https://github.com/matrix-org/matrix-react-sdk/pull/9047)). Contributed by @kerryarchibald.
  * Improve _FilePanel.scss ([\#9031](https://github.com/matrix-org/matrix-react-sdk/pull/9031)). Contributed by @luixxiul.
  * Improve spotlight accessibility by adding context menus ([\#8907](https://github.com/matrix-org/matrix-react-sdk/pull/8907)). Fixes #20875 and #22675. Contributed by @justjanne.
  * Bug Fixes
  * Replace mask-images with svg components in MessageActionBar ([\#9088](https://github.com/matrix-org/matrix-react-sdk/pull/9088)). Fixes #22912. Contributed by @kerryarchibald.
  * Unbreak in-app permalink tooltips ([\#9087](https://github.com/matrix-org/matrix-react-sdk/pull/9087)). Fixes #22874.
  * Show a back button when viewing a space member ([\#9095](https://github.com/matrix-org/matrix-react-sdk/pull/9095)). Fixes #22898.
  * Align the right edge of info tile lines with normal ones on IRC layout ([\#9058](https://github.com/matrix-org/matrix-react-sdk/pull/9058)). Fixes #22871. Contributed by @luixxiul.
  * Prevent email verification from overriding existing sessions ([\#9075](https://github.com/matrix-org/matrix-react-sdk/pull/9075)). Fixes #22881. Contributed by @justjanne.
  * Fix wrong buttons being used when exploring public rooms ([\#9062](https://github.com/matrix-org/matrix-react-sdk/pull/9062)). Fixes #22862.
  * Re-add padding to generic event list summary on IRC layout ([\#9063](https://github.com/matrix-org/matrix-react-sdk/pull/9063)). Fixes #22869. Contributed by @luixxiul.
  * Joining federated rooms via the spotlight search should no longer cause a "No known servers" error. ([\#9055](https://github.com/matrix-org/matrix-react-sdk/pull/9055)). Fixes #22845. Contributed by @Half-Shot.
* Thu Jul  7 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.11.0
  * Features
    Document how to configure a custom home.html. (#21066). Contributed by @johannes-krude.
    Move New Search Experience out of beta (#8859). Contributed by @justjanne.
    Switch video rooms to spotlight layout when in PiP mode (#8912). Fixes #22574.
    Live location sharing - render message deleted tile for redacted beacons (#8905). Contributed by @kerryarchibald.
    Improve view source dialog style (#8883). Fixes #22636. Contributed by @luixxiul.
    Improve integration manager dialog style (#8888). Fixes #22642. Contributed by @luixxiul.
    Implement MSC3827: Filtering of /publicRooms by room type (#8866). Fixes #22578.
    Show chat panel when opening a video room with unread messages (#8812). Fixes #22527.
    Live location share - forward latest location (#8860). Contributed by @kerryarchibald.
    Allow integration managers to validate user identity after opening (#8782). Contributed by @Half-Shot.
    Create a common header on right panel cards on BaseCard (#8808). Contributed by @luixxiul.
    Integrate searching public rooms and people into the new search experience (#8707). Fixes #21354 and #19349. Contributed by @justjanne.
    Bring back waveform for voice messages and retain seeking (#8843). Fixes #21904.
    Improve colors in settings (#7283).
    Keep draft in composer when a slash command syntax errors (#8811). Fixes #22384.
    Release video rooms as a beta feature (#8431).
    Clarify logout key backup warning dialog. Contributed by @notramo. (#8741). Fixes #15565. Contributed by @MadLittleMods.
    Slightly improve the look of the Message edits dialog (#8763). Fixes #22410.
    Add support for MD / HTML in room topics (#8215). Fixes #5180. Contributed by @Johennes.
    Live location share - link to timeline tile from share warning (#8752). Contributed by @kerryarchibald.
    Improve composer visiblity (#8578). Fixes #22072 and #17362.
    Makes the avatar of the user menu non-draggable (#8765). Contributed by @luixxiul.
    Improve widget buttons behaviour and layout (#8734).
    Use AccessibleButton for 'Reset All' link button on SetupEncryptionBody (#8730). Contributed by @luixxiul.
    Adjust message timestamp position on TimelineCard in non-bubble layouts (#8745). Fixes #22426. Contributed by @luixxiul.
    Use AccessibleButton for 'In reply to' link button on ReplyChain (#8726). Fixes #22407. Contributed by @luixxiul.
    Live location share - enable reply and react to tiles (#8721). Contributed by @kerryarchibald.
    Change dash to em dash issues fixed (#8455). Fixes #21895. Contributed by @goelesha.
  * Bug fixes
    Reduce video rooms log spam (#22665).
    Connect to Jitsi unmuted by default (#22660). Fixes #22637.
    Work around a Jitsi bug with display name encoding (#22525). Fixes #22521.
    Make invite dialogue fixed height (#8945).
    Correct issue with tab order in new search experience (#8919). Fixes #22670. Contributed by @justjanne.
    Clicking location replies now redirects to the replied event instead of opening the map (#8918). Fixes #22667.
    Keep clicks on pills within the app (#8917). Fixes #22653.
    Don't overlap tile bubbles with timestamps in modern layout (#8908). Fixes #22425.
    Connect to Jitsi unmuted by default (#8909).
    Maximize width value of display name on TimelineCard with IRC/modern layout (#8904). Fixes #22651. Contributed by @luixxiul.
    Align the avatar and the display name on TimelineCard (#8900). Contributed by @luixxiul.
    Remove inline margin from reactions row on IRC layout (#8891). Fixes #22644. Contributed by @luixxiul.
    Align "From a thread" on search result panel on IRC layout (#8892). Fixes #22645. Contributed by @luixxiul.
    Display description of E2E advanced panel as subsection text (#8889). Contributed by @luixxiul.
    Remove inline end margin from images on file panel (#8886). Fixes #22640. Contributed by @luixxiul.
    Disable option to Quote when we don't have sufficient permissions (#8893). Fixes #22643.
    Add padding to font scaling loader for message bubble layout (#8875). Fixes #22626. Contributed by @luixxiul.
    Set 100%% max-width to display name on reply tiles (#8867). Fixes #22615. Contributed by @luixxiul.
    Fix alignment of pill letter (#8874). Fixes #22622. Contributed by @luixxiul.
    Move the beta pill to the right side and display the pill on video room only (#8873). Fixes #22619 and #22620. Contributed by @luixxiul.
    Stop using absolute property to place beta pill on RoomPreviewCard (#8872). Fixes #22617. Contributed by @luixxiul.
    Make the pill text single line (#8744). Fixes #22427. Contributed by @luixxiul.
    Hide overflow of public room description on spotlight dialog result (#8870). Contributed by @luixxiul.
    Fix position of message action bar on the info tile on TimelineCard in message bubble layout (#8865). Fixes #22614. Contributed by @luixxiul.
    Remove inline start margin from display name on reply tiles on TimelineCard (#8864). Fixes #22613. Contributed by @luixxiul.
    Improve homeserver dropdown dialog styling (#8850). Fixes #22552. Contributed by @justjanne.
    Fix crash when drawing blurHash for portrait videos PSB-139 (#8855). Fixes #22597. Contributed by @andybalaam.
    Fix grid blowout on pinned event tiles (#8816). Fixes #22543. Contributed by @luixxiul.
    Fix temporary sync errors if there's weird settings stored in account data (#8857).
    Fix reactions row overflow and gap between reactions (#8813). Fixes #22093. Contributed by @luixxiul.
    Fix issues with the Create new room button in Spotlight (#8851). Contributed by @justjanne.
    Remove margin from E2E icon between avatar and hidden event (#8584). Fixes #22186. Contributed by @luixxiul.
    Fix waveform on a message bubble (#8852). Contributed by @luixxiul.
    Location sharing maps are now loaded after reconnection (#8848). Fixes #20993.
    Update the avatar mask so it doesn’t cut off spaces’ avatars anymore (#8849). Contributed by @justjanne.
    Add a bit of safety around timestamp handling for threads (#8845).
    Remove top margin from event tile on a narrow viewport (#8814). Contributed by @luixxiul.
    Fix keyboard shortcuts on settings tab being wrapped (#8825). Fixes #22547. Contributed by @luixxiul.
    Add try-catch around blurhash loading (#8830).
    Prevent new composer from overflowing from non-breakable text (#8829). Fixes #22507. Contributed by @justjanne.
    Use common subheading on sidebar user settings tab (#8823). Contributed by @luixxiul.
    Fix clickable area of advanced toggle on appearance user settings tab (#8820). Fixes #22546. Contributed by @luixxiul.
    Disable redacting reactions if we don't have sufficient permissions (#8767). Fixes #22262.
    Update the live timeline when the JS SDK resets it (#8806). Fixes #22421.
    Fix flex blowout on image reply (#8809). Fixes #22509 and #22510. Contributed by @luixxiul.
    Enable background color on hover for chat panel and thread panel (#8644). Fixes #22273. Contributed by @luixxiul.
    Fix #20026: send read marker as soon as we change it (#8802). Fixes #20026. Contributed by @andybalaam.
    Allow AppTiles to shrink as much as necessary (#8805). Fixes #22499.
    Make widgets in video rooms immutable again (#8803). Fixes #22497.
    Use MessageActionBar style declarations on pinned message card (#8757). Fixes #22444. Contributed by @luixxiul.
    Expire video member events after 1 hour (#8776).
    Name lists on invite dialog (#8046). Fixes #21400 and #19463. Contributed by @luixxiul.
    Live location share - show loading UI for beacons with start timestamp in the future (#8775). Fixes #22437. Contributed by @kerryarchibald.
    Fix scroll jump issue with the composer (#8788). Fixes #22464.
    Fix the incorrect nesting of download button on MessageActionBar (#8785). Contributed by @luixxiul.
    Revert link color change in composer (#8784). Fixes #22468.
    Fix 'Logout' inline link on the splash screen (#8770). Fixes #22449. Contributed by @luixxiul.
    Fix disappearing widget poput button when changing the widget layout (#8754).
    Reduce gutter with the new read receipt UI (#8736). Fixes #21890.
    Add ellipsis effect to hidden beacon status (#8755). Fixes #22441. Contributed by @luixxiul.
    Make the pill on the basic message composer compatible with display name in RTL languages (#8758). Fixes #22445. Contributed by @luixxiul.
    Prevent the banner text from being selected, replacing the spacing values with the variable (#8756). Fixes #22442. Contributed by @luixxiul.
    Ensure the first device on a newly-registered account gets cross-signed properly (#8750). Fixes #21977. Contributed by @duxovni.
    Hide live location option in threads composer (#8746). Fixes #22424. Contributed by @kerryarchibald.
    Make sure MessageTimestamp is not hidden by EventTile_line on TimelineCard (#8748). Contributed by @luixxiul.
    Make PiP motion smoother and react to window resizes correctly (#8747). Fixes #22292.
    Prevent Invite and DevTools dialogs from being cut off (#8646). Fixes #20911 and undefined/matrix-react-sdk#8165. Contributed by @justjanne.
    Squish event bubble tiles less (#8740).
    Use random widget IDs for video rooms (#8739). Fixes #22417.
    Fix read avatars overflow from the right chat panel with a maximized widget on bubble message layout (#8470). Contributed by @luixxiul.
    Fix CallView crash (#8735). Fixes #22394.
* Wed Jun 15 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.10.15
  * Fix missing element desktop preferences
* Tue Jun 14 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.10.14
  * Live location sharing
  * Allow disabling hw acceleration
* Fri Jun  3 2022 Mathias Homann <Mathias.Homann@opensuse.org>
- Version 1.10.13
  * Features
  [#] Go to space landing page when clicking on a selected space (#6442). Fixes vector-im/element-web#20296.
  [#] Fall back to untranslated string rather than showing missing translation error (#8609).
  [#] Show file name and size on images on hover (#6511). Fixes vector-im/element-web#18197.
  [#] Iterate on search results for message bubbles (#7047). Fixes vector-im/element-web#20315.
  [#] registration: redesign email verification page (#8554). Fixes vector-im/element-web#21984.
  [#] Show full thread message in hover title on thread summary (#8568). Fixes vector-im/element-web#22037.
  [#] Tweak video rooms copy (#8582). Fixes vector-im/element-web#22176.
  [#] Live location share - beacon tooltip in maximised view (#8572).
  [#] Add dialog to navigate long room topics (#8517). Fixes vector-im/element-web#9623.
  [#] Change spaceroomfacepile tooltip if memberlist is shown (#8571). Fixes vector-im/element-web#17406.
  [#] Improve message editing UI (#8483). Fixes vector-im/element-web#9752 and vector-im/element-web#22108.
  [#] Make date changes more obvious (#6410). Fixes vector-im/element-web#16221.
  [#] Enable forwarding static locations (#8553).
  [#] Log TimelinePanel debugging info when opening the bug report modal (#8502).
  [#] Improve welcome screen, add opt-out analytics (#8474). Fixes vector-im/element-web#21946.
  [#] Converting selected text to MD link when pasting a URL (#8242). Fixes vector-im/element-web#21634. Contributed by @Sinharitik589.
  [#] Support Inter on custom themes (#8399). Fixes vector-im/element-web#16293.
  [#] Add a Copy link button to the right-click message context-menu labs feature (#8527).
  [#] Move widget screenshots labs flag to devtools (#8522).
  [#] Remove some labs features which don't get used or create maintenance burden: custom status, multiple integration managers, and do not disturb (#8521).
  [#] Add a way to toggle ScrollPanel and TimelinePanel debug logs (#8513).
  [#] Spaces: remove blue beta dot (#8511). Fixes vector-im/element-web#22061.
  [#] Order new search dialog results by recency (#8444).
  [#] Improve pills (#6398). Fixes vector-im/element-web#16948 and vector-im/element-web#21281.
  [#] Add a way to maximize/pin widget from the PiP view (#7672). Fixes vector-im/element-web#20723.
  [#] Iterate video room designs in labs (#8499).
  [#] Improve UI/UX in calls (#7791). Fixes vector-im/element-web#19937.
  [#] Add ability to change audio and video devices during a call (#7173). Fixes vector-im/element-web#15595.
  * Bug Fixes
  [#] Fix video rooms sometimes connecting muted when they shouldn't (#22125).
  [#] Avoid flashing the 'join conference' button at the user in video rooms (#22120).
  [#] Fully close Jitsi conferences on errors (#22060).
  [#] Fix click behavior of notification badges on spaces (#8627). Fixes vector-im/element-web#22241.
  [#] Add missing return values in Read Receipt animation code (#8625). Fixes vector-im/element-web#22175.
  [#] Fix 'continue' button not working after accepting identity server terms of service (#8619). Fixes vector-im/element-web#20003.
  [#] Proactively fix stuck devices in video rooms (#8587). Fixes vector-im/element-web#22131.
  [#] Fix position of the message action bar on left side bubbles (#8398). Fixes vector-im/element-web#21879. Contributed by @luixxiul.
  [#] Fix edge case thread summaries around events without a msgtype (#8576).
  [#] Fix favourites metaspace not updating (#8594). Fixes vector-im/element-web#22156.
  [#] Stop spaces from displaying as rooms in new breadcrumbs (#8595). Fixes vector-im/element-web#22165.
  [#] Fix avatar position of hidden event on ThreadView (#8592). Fixes vector-im/element-web#22199. Contributed by @luixxiul.
  [#] Fix MessageTimestamp position next to redacted messages on IRC/modern layout (#8591). Fixes vector-im/element-web#22181. Contributed by @luixxiul.
  [#] Fix padding of messages in threads (#8574). Contributed by @luixxiul.
  [#] Enable overflow of hidden events content (#8585). Fixes vector-im/element-web#22187. Contributed by @luixxiul.
  [#] Increase composer line height to avoid cutting off emoji (#8583). Fixes vector-im/element-web#22170.
  [#] Don't consider threads for breaking continuation until actually created (#8581). Fixes vector-im/element-web#22164.
  [#] Fix displaying hidden events on threads (#8555). Fixes vector-im/element-web#22058. Contributed by @luixxiul.
  [#] Fix button width and align 絵文字 (emoji) on the user panel (#8562). Fixes vector-im/element-web#22142. Contributed by @luixxiul.
  [#] Standardise the margin for settings tabs (#7963). Fixes vector-im/element-web#20767. Contributed by @yuktea.
  [#] Fix room history not being visible even if we have historical keys (#8563). Fixes vector-im/element-web#16983.
  [#] Fix oblong avatars in video room lobbies (#8565).
  [#] Update thread summary when latest event gets decrypted (#8564). Fixes vector-im/element-web#22151.
  [#] Fix codepath which can wrongly cause automatic space switch from all rooms (#8560). Fixes vector-im/element-web#21373.
  [#] Fix effect of URL preview toggle not updating live (#8561). Fixes vector-im/element-web#22148.
  [#] Fix visual bugs on AccessSecretStorageDialog (#8160). Fixes vector-im/element-web#19426. Contributed by @luixxiul.
  [#] Fix the width bounce of the clock on the AudioPlayer (#8320). Fixes vector-im/element-web#21788. Contributed by @luixxiul.
  [#] Hide the verification left stroke only on the thread list (#8525). Fixes vector-im/element-web#22132. Contributed by @luixxiul.
  [#] Hide recently_viewed dropdown when other modal opens (#8538). Contributed by @yaya-usman.
  [#] Only jump to date after pressing the 'go' button (#8548). Fixes vector-im/element-web#20799.
  [#] Fix download button not working on events that were decrypted too late (#8556). Fixes vector-im/element-web#19427.
  [#] Align thread summary button with bubble messages on the left side (#8388). Fixes vector-im/element-web#21873. Contributed by @luixxiul.
  [#] Fix unresponsive notification toggles (#8549). Fixes vector-im/element-web#22109.
  [#] Set color-scheme property in themes (#8547). Fixes vector-im/element-web#22124.
  [#] Improve the styling of error messages during search initialization. (#6899). Fixes vector-im/element-web#19245 and vector-im/element-web#18164. Contributed by @KalleStruik.
  [#] Don't leave button tooltips open when closing modals (#8546). Fixes vector-im/element-web#22121.
  [#] update matrix-analytics-events (#8543).
  [#] Handle Jitsi Meet crashes more gracefully (#8541).
  [#] Fix regression around pasting links (#8537). Fixes vector-im/element-web#22117.
  [#] Fixes suggested room not ellipsized on shrinking (#8536). Contributed by @yaya-usman.
  [#] Add global spacing between display name and location body (#8523). Fixes vector-im/element-web#22111. Contributed by @luixxiul.
  [#] Add box-shadow to the reply preview on the main (left) panel only (#8397). Fixes vector-im/element-web#21894. Contributed by @luixxiul.
  [#] Set line-height: 1 to RedactedBody inside GenericEventListSummary for IRC/modern layout (#8529). Fixes vector-im/element-web#22112. Contributed by @luixxiul.
  [#] Fix position of timestamp on the chat panel in IRC layout and message edits history modal window (#8464). Fixes vector-im/element-web#22011 and vector-im/element-web#22014. Contributed by @luixxiul.
  [#] Fix unexpected and inconsistent inheritance of line-height property for mx_TextualEvent (#8485). Fixes vector-im/element-web#22041. Contributed by @luixxiul.
  [#] Set the same margin to the right side of NewRoomIntro on TimelineCard (#8453). Contributed by @luixxiul.
  [#] Remove duplicate tooltip from user pills (#8512).
  [#] Set max-width for MLocationBody and MLocationBody_map by default (#8519). Fixes vector-im/element-web#21983. Contributed by @luixxiul.
  [#] Simplify ReplyPreview UI implementation (#8516). Fixes vector-im/element-web#22091. Contributed by @luixxiul.
  [#] Fix thread summary overflow on narrow message panel on bubble message layout (#8520). Fixes vector-im/element-web#22097. Contributed by @luixxiul.
  [#] Live location sharing - refresh beacon timers on tab becoming active (#8515).
  [#] Enlarge emoji again (#8509). Fixes vector-im/element-web#22086.
  [#] Order receipts with the most recent on the right (#8506). Fixes vector-im/element-web#22044.
  [#] Disconnect from video rooms when leaving (#8500).
  [#] Fix soft crash around threads when room isn't yet in store (#8496). Fixes vector-im/element-web#22047.
  [#] Fix reading of cached room device setting values (#8491).
  [#] Add loading spinners to threads panels (#8490). Fixes vector-im/element-web#21335.
  [#] Fix forwarding UI papercuts (#8482). Fixes vector-im/element-web#17616.
* Mon May 16 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.10.12
  * Improved threading support
  * Implement new Read Receipt design
* Tue Apr 12 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.10.9
  * Threading support
  * APNG support
  * Live location sharing
* Wed Mar 30 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Sync ExclusiveArch with nodejs-electron: %%{ix86} %%{arm}
* Mon Mar 21 2022 Dominik Heidler <dheidler@suse.de>
- Use right build dir for aarch64 (boo#1197278)
* Fri Mar 18 2022 Dominik Heidler <dheidler@suse.de>
- Fix build on other architectures (boo#1197278)
* Thu Mar 17 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.10.4
  * Improved build process: Perform actual build in OBS
* Mon Jan 31 2022 Dominik Heidler <dheidler@suse.de>
- Version 1.9.9
  * Hardening for CVE-2022-23597
* Fri Jan  7 2022 Fusion Future <qydwhotmail@gmail.com>
- Desktop file enhancement:
  * Add keywords.
  * Add GenericName.
  * Add "X-GNOME-SingleWindow=true".
  * Add zh_CN and zh_TW translations.
* Thu Dec 30 2021 Dominik Heidler <dheidler@suse.de>
- Version 1.9.8
  * Mostly small bugfixes and minor improvements
  * Fix WebGL
  * See https://github.com/vector-im/element-desktop/releases/tag/v1.9.8
* Mon Dec 13 2021 Dominik Heidler <dheidler@suse.de>
- Version 1.9.7
  * Security fix: buffer overflow in libolm and matrix-js-sdk
    https://matrix.org/blog/2021/12/13/disclosure-buffer-overflow-in-libolm-and-matrix-js-sdk
* Wed Dec  8 2021 Sunsheep <me@sunsheep.net>
- Version 1.9.6
  * UI fixes and improvements
  * implement more meta-spaces
  * Fix possible infinite loop on widget start
* Mon Oct 18 2021 Dominik Heidler <dheidler@suse.de>
- Version 1.9.2
  * UI fixes
  * Upgrade to matrix-js-sdk#14.0.1
* Mon Sep 13 2021 Dominik Heidler <dheidler@suse.de>
- Version 1.8.4
  * Fix a security issue with message key sharing
* Tue Aug 10 2021 Dominik Heidler <dheidler@suse.de>
- Version 1.7.33
  * Translation update
  * New Labs feature: feature_report_to_moderators
  * Dependency updates
  * Add libera.chat to default room directory
* Fri Jun 25 2021 Dominik Heidler <dheidler@suse.com>
- Version 1.7.31
* Tue May 18 2021 Dominik Heidler <dheidler@suse.com>
- Version 1.7.28
